/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.23
 *
 * Copyright (c) 2020 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWidgets.h"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qstyle.sip"
#include <qstyle.h>
#line 29 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"

#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 33 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 39 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 28 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 42 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qsizepolicy.sip"
#include <qsizepolicy.h>
#line 45 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtCore/qrect.sip"
#include <qrect.h>
#line 48 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 51 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtCore/qsize.sip"
#include <qsize.h>
#line 54 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 57 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtGui/qpixmap.sip"
#include <qpixmap.h>
#line 60 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtGui/qicon.sip"
#include <qicon.h>
#line 63 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 886 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 66 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 712 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qstyleoption.sip"
#include <qstyleoption.h>
#line 69 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 72 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 75 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 27 "sip/QtCore/qstring.sip"
#include <qstring.h>
#line 78 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtGui/qfontmetrics.sip"
#include <qfontmetrics.h>
#line 81 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 36 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/sip/QtWidgets/qapplication.sip"
#include <qapplication.h>
#line 84 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 89 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 92 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 95 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 247 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 98 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 235 "sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 101 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 28 "sip/QtCore/qobject.sip"
#include <qobject.h>
#line 104 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 107 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 38 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 110 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 30 "sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 113 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 149 "sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 116 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtCore/qthread.sip"
#include <qthread.h>
#line 119 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 122 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 125 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 128 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"
#line 26 "sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 131 "/scratch/jenkins-BUILDS-eSDK-2023.1_stable-pipeline-build_async-47_k26_smk_kv_full/build/tmp/work/cortexa72-cortexa53-xilinx-linux/python3-pyqt5/5.15.1-r0/PyQt5-5.15.1/QtWidgets/sipQtWidgetsQStyle.cpp"


class sipQStyle : public  ::QStyle
{
public:
    sipQStyle();
    virtual ~sipQStyle();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    int layoutSpacing( ::QSizePolicy::ControlType, ::QSizePolicy::ControlType, ::Qt::Orientation,const  ::QStyleOption*,const  ::QWidget*) const SIP_OVERRIDE;
     ::QPixmap generatedIconPixmap( ::QIcon::Mode,const  ::QPixmap&,const  ::QStyleOption*) const SIP_OVERRIDE;
     ::QIcon standardIcon( ::QStyle::StandardPixmap,const  ::QStyleOption*,const  ::QWidget*) const SIP_OVERRIDE;
     ::QPixmap standardPixmap( ::QStyle::StandardPixmap,const  ::QStyleOption*,const  ::QWidget*) const SIP_OVERRIDE;
    int styleHint( ::QStyle::StyleHint,const  ::QStyleOption*,const  ::QWidget*, ::QStyleHintReturn*) const SIP_OVERRIDE;
     ::QSize sizeFromContents( ::QStyle::ContentsType,const  ::QStyleOption*,const  ::QSize&,const  ::QWidget*) const SIP_OVERRIDE;
    int pixelMetric( ::QStyle::PixelMetric,const  ::QStyleOption*,const  ::QWidget*) const SIP_OVERRIDE;
     ::QRect subControlRect( ::QStyle::ComplexControl,const  ::QStyleOptionComplex*, ::QStyle::SubControl,const  ::QWidget*) const SIP_OVERRIDE;
     ::QStyle::SubControl hitTestComplexControl( ::QStyle::ComplexControl,const  ::QStyleOptionComplex*,const  ::QPoint&,const  ::QWidget*) const SIP_OVERRIDE;
    void drawComplexControl( ::QStyle::ComplexControl,const  ::QStyleOptionComplex*, ::QPainter*,const  ::QWidget*) const SIP_OVERRIDE;
     ::QRect subElementRect( ::QStyle::SubElement,const  ::QStyleOption*,const  ::QWidget*) const SIP_OVERRIDE;
    void drawControl( ::QStyle::ControlElement,const  ::QStyleOption*, ::QPainter*,const  ::QWidget*) const SIP_OVERRIDE;
    void drawPrimitive( ::QStyle::PrimitiveElement,const  ::QStyleOption*, ::QPainter*,const  ::QWidget*) const SIP_OVERRIDE;
     ::QPalette standardPalette() const SIP_OVERRIDE;
    void drawItemPixmap( ::QPainter*,const  ::QRect&,int,const  ::QPixmap&) const SIP_OVERRIDE;
    void drawItemText( ::QPainter*,const  ::QRect&,int,const  ::QPalette&,bool,const  ::QString&, ::QPalette::ColorRole) const SIP_OVERRIDE;
     ::QRect itemPixmapRect(const  ::QRect&,int,const  ::QPixmap&) const SIP_OVERRIDE;
     ::QRect itemTextRect(const  ::QFontMetrics&,const  ::QRect&,int,bool,const  ::QString&) const SIP_OVERRIDE;
    void polish( ::QPalette&) SIP_OVERRIDE;
    void unpolish( ::QApplication*) SIP_OVERRIDE;
    void polish( ::QApplication*) SIP_OVERRIDE;
    void unpolish( ::QWidget*) SIP_OVERRIDE;
    void polish( ::QWidget*) SIP_OVERRIDE;
    bool event( ::QEvent*) SIP_OVERRIDE;
    bool eventFilter( ::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent( ::QTimerEvent*) SIP_OVERRIDE;
    void childEvent( ::QChildEvent*) SIP_OVERRIDE;
    void customEvent( ::QEvent*) SIP_OVERRIDE;
    void connectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const  ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQStyle(const sipQStyle &);
    sipQStyle &operator = (const sipQStyle &);

    char sipPyMethods[30];
};

sipQStyle::sipQStyle():  ::QStyle(), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQStyle::~sipQStyle()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQStyle::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWidgets_qt_metaobject(sipPySelf,sipType_QStyle);

    return  ::QStyle::metaObject();
}

int sipQStyle::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::QStyle::qt_metacall(_c,_id,_a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWidgets_qt_metacall(sipPySelf,sipType_QStyle,_c,_id,_a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQStyle::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWidgets_qt_metacast(sipPySelf, sipType_QStyle, _clname, &sipCpp) ? sipCpp :  ::QStyle::qt_metacast(_clname));
}

int sipQStyle::layoutSpacing( ::QSizePolicy::ControlType a0, ::QSizePolicy::ControlType a1, ::Qt::Orientation a2,const  ::QStyleOption*a3,const  ::QWidget*a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[0]),sipPySelf,sipName_QStyle,sipName_layoutSpacing);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtWidgets_107(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QSizePolicy::ControlType, ::QSizePolicy::ControlType, ::Qt::Orientation,const  ::QStyleOption*,const  ::QWidget*);

    return sipVH_QtWidgets_107(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

 ::QPixmap sipQStyle::generatedIconPixmap( ::QIcon::Mode a0,const  ::QPixmap& a1,const  ::QStyleOption*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[1]),sipPySelf,sipName_QStyle,sipName_generatedIconPixmap);

    if (!sipMeth)
        return  ::QPixmap();

    extern  ::QPixmap sipVH_QtWidgets_106(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QIcon::Mode,const  ::QPixmap&,const  ::QStyleOption*);

    return sipVH_QtWidgets_106(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

 ::QIcon sipQStyle::standardIcon( ::QStyle::StandardPixmap a0,const  ::QStyleOption*a1,const  ::QWidget*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[2]),sipPySelf,sipName_QStyle,sipName_standardIcon);

    if (!sipMeth)
        return  ::QIcon();

    extern  ::QIcon sipVH_QtWidgets_105(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QStyle::StandardPixmap,const  ::QStyleOption*,const  ::QWidget*);

    return sipVH_QtWidgets_105(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

 ::QPixmap sipQStyle::standardPixmap( ::QStyle::StandardPixmap a0,const  ::QStyleOption*a1,const  ::QWidget*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[3]),sipPySelf,sipName_QStyle,sipName_standardPixmap);

    if (!sipMeth)
        return  ::QPixmap();

    extern  ::QPixmap sipVH_QtWidgets_104(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QStyle::StandardPixmap,const  ::QStyleOption*,const  ::QWidget*);

    return sipVH_QtWidgets_104(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

int sipQStyle::styleHint( ::QStyle::StyleHint a0,const  ::QStyleOption*a1,const  ::QWidget*a2, ::QStyleHintReturn*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[4]),sipPySelf,sipName_QStyle,sipName_styleHint);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtWidgets_103(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QStyle::StyleHint,const  ::QStyleOption*,const  ::QWidget*, ::QStyleHintReturn*);

    return sipVH_QtWidgets_103(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

 ::QSize sipQStyle::sizeFromContents( ::QStyle::ContentsType a0,const  ::QStyleOption*a1,const  ::QSize& a2,const  ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[5]),sipPySelf,sipName_QStyle,sipName_sizeFromContents);

    if (!sipMeth)
        return  ::QSize();

    extern  ::QSize sipVH_QtWidgets_102(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QStyle::ContentsType,const  ::QStyleOption*,const  ::QSize&,const  ::QWidget*);

    return sipVH_QtWidgets_102(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

int sipQStyle::pixelMetric( ::QStyle::PixelMetric a0,const  ::QStyleOption*a1,const  ::QWidget*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[6]),sipPySelf,sipName_QStyle,sipName_pixelMetric);

    if (!sipMeth)
        return 0;

    extern int sipVH_QtWidgets_101(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QStyle::PixelMetric,const  ::QStyleOption*,const  ::QWidget*);

    return sipVH_QtWidgets_101(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

 ::QRect sipQStyle::subControlRect( ::QStyle::ComplexControl a0,const  ::QStyleOptionComplex*a1, ::QStyle::SubControl a2,const  ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[7]),sipPySelf,sipName_QStyle,sipName_subControlRect);

    if (!sipMeth)
        return  ::QRect();

    extern  ::QRect sipVH_QtWidgets_100(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QStyle::ComplexControl,const  ::QStyleOptionComplex*, ::QStyle::SubControl,const  ::QWidget*);

    return sipVH_QtWidgets_100(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

 ::QStyle::SubControl sipQStyle::hitTestComplexControl( ::QStyle::ComplexControl a0,const  ::QStyleOptionComplex*a1,const  ::QPoint& a2,const  ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[8]),sipPySelf,sipName_QStyle,sipName_hitTestComplexControl);

    if (!sipMeth)
        return  ::QStyle::SC_None;

    extern  ::QStyle::SubControl sipVH_QtWidgets_99(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QStyle::ComplexControl,const  ::QStyleOptionComplex*,const  ::QPoint&,const  ::QWidget*);

    return sipVH_QtWidgets_99(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

void sipQStyle::drawComplexControl( ::QStyle::ComplexControl a0,const  ::QStyleOptionComplex*a1, ::QPainter*a2,const  ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[9]),sipPySelf,sipName_QStyle,sipName_drawComplexControl);

    if (!sipMeth)
        return;

    extern void sipVH_QtWidgets_98(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QStyle::ComplexControl,const  ::QStyleOptionComplex*, ::QPainter*,const  ::QWidget*);

    sipVH_QtWidgets_98(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

 ::QRect sipQStyle::subElementRect( ::QStyle::SubElement a0,const  ::QStyleOption*a1,const  ::QWidget*a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[10]),sipPySelf,sipName_QStyle,sipName_subElementRect);

    if (!sipMeth)
        return  ::QRect();

    extern  ::QRect sipVH_QtWidgets_97(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QStyle::SubElement,const  ::QStyleOption*,const  ::QWidget*);

    return sipVH_QtWidgets_97(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQStyle::drawControl( ::QStyle::ControlElement a0,const  ::QStyleOption*a1, ::QPainter*a2,const  ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[11]),sipPySelf,sipName_QStyle,sipName_drawControl);

    if (!sipMeth)
        return;

    extern void sipVH_QtWidgets_96(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QStyle::ControlElement,const  ::QStyleOption*, ::QPainter*,const  ::QWidget*);

    sipVH_QtWidgets_96(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

void sipQStyle::drawPrimitive( ::QStyle::PrimitiveElement a0,const  ::QStyleOption*a1, ::QPainter*a2,const  ::QWidget*a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[12]),sipPySelf,sipName_QStyle,sipName_drawPrimitive);

    if (!sipMeth)
        return;

    extern void sipVH_QtWidgets_95(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QStyle::PrimitiveElement,const  ::QStyleOption*, ::QPainter*,const  ::QWidget*);

    sipVH_QtWidgets_95(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

 ::QPalette sipQStyle::standardPalette() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[13]),sipPySelf,SIP_NULLPTR,sipName_standardPalette);

    if (!sipMeth)
        return  ::QStyle::standardPalette();

    extern  ::QPalette sipVH_QtWidgets_94(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWidgets_94(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipQStyle::drawItemPixmap( ::QPainter*a0,const  ::QRect& a1,int a2,const  ::QPixmap& a3) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[14]),sipPySelf,SIP_NULLPTR,sipName_drawItemPixmap);

    if (!sipMeth)
    {
         ::QStyle::drawItemPixmap(a0,a1,a2,a3);
        return;
    }

    extern void sipVH_QtWidgets_93(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QPainter*,const  ::QRect&,int,const  ::QPixmap&);

    sipVH_QtWidgets_93(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

void sipQStyle::drawItemText( ::QPainter*a0,const  ::QRect& a1,int a2,const  ::QPalette& a3,bool a4,const  ::QString& a5, ::QPalette::ColorRole a6) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[15]),sipPySelf,SIP_NULLPTR,sipName_drawItemText);

    if (!sipMeth)
    {
         ::QStyle::drawItemText(a0,a1,a2,a3,a4,a5,a6);
        return;
    }

    extern void sipVH_QtWidgets_92(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QPainter*,const  ::QRect&,int,const  ::QPalette&,bool,const  ::QString&, ::QPalette::ColorRole);

    sipVH_QtWidgets_92(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4, a5, a6);
}

 ::QRect sipQStyle::itemPixmapRect(const  ::QRect& a0,int a1,const  ::QPixmap& a2) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[16]),sipPySelf,SIP_NULLPTR,sipName_itemPixmapRect);

    if (!sipMeth)
        return  ::QStyle::itemPixmapRect(a0,a1,a2);

    extern  ::QRect sipVH_QtWidgets_91(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QRect&,int,const  ::QPixmap&);

    return sipVH_QtWidgets_91(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

 ::QRect sipQStyle::itemTextRect(const  ::QFontMetrics& a0,const  ::QRect& a1,int a2,bool a3,const  ::QString& a4) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,const_cast<char *>(&sipPyMethods[17]),sipPySelf,SIP_NULLPTR,sipName_itemTextRect);

    if (!sipMeth)
        return  ::QStyle::itemTextRect(a0,a1,a2,a3,a4);

    extern  ::QRect sipVH_QtWidgets_90(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QFontMetrics&,const  ::QRect&,int,bool,const  ::QString&);

    return sipVH_QtWidgets_90(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3, a4);
}

void sipQStyle::polish( ::QPalette& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[18],sipPySelf,SIP_NULLPTR,sipName_polish);

    if (!sipMeth)
    {
         ::QStyle::polish(a0);
        return;
    }

    extern void sipVH_QtWidgets_89(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QPalette&);

    sipVH_QtWidgets_89(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStyle::unpolish( ::QApplication*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[19],sipPySelf,SIP_NULLPTR,sipName_unpolish);

    if (!sipMeth)
    {
         ::QStyle::unpolish(a0);
        return;
    }

    extern void sipVH_QtWidgets_88(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QApplication*);

    sipVH_QtWidgets_88(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStyle::polish( ::QApplication*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[20],sipPySelf,SIP_NULLPTR,sipName_polish);

    if (!sipMeth)
    {
         ::QStyle::polish(a0);
        return;
    }

    extern void sipVH_QtWidgets_88(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QApplication*);

    sipVH_QtWidgets_88(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStyle::unpolish( ::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[21],sipPySelf,SIP_NULLPTR,sipName_unpolish);

    if (!sipMeth)
    {
         ::QStyle::unpolish(a0);
        return;
    }

    extern void sipVH_QtWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QWidget*);

    sipVH_QtWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStyle::polish( ::QWidget*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[22],sipPySelf,SIP_NULLPTR,sipName_polish);

    if (!sipMeth)
    {
         ::QStyle::polish(a0);
        return;
    }

    extern void sipVH_QtWidgets_47(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QWidget*);

    sipVH_QtWidgets_47(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQStyle::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[23],sipPySelf,SIP_NULLPTR,sipName_event);

    if (!sipMeth)
        return  ::QStyle::event(a0);

    extern bool sipVH_QtWidgets_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_QtWidgets_5(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQStyle::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[24],sipPySelf,SIP_NULLPTR,sipName_eventFilter);

    if (!sipMeth)
        return  ::QStyle::eventFilter(a0,a1);

    extern bool sipVH_QtWidgets_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_QtWidgets_4(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQStyle::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[25],sipPySelf,SIP_NULLPTR,sipName_timerEvent);

    if (!sipMeth)
    {
         ::QStyle::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_QtWidgets_3(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStyle::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[26],sipPySelf,SIP_NULLPTR,sipName_childEvent);

    if (!sipMeth)
    {
         ::QStyle::childEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_QtWidgets_2(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStyle::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[27],sipPySelf,SIP_NULLPTR,sipName_customEvent);

    if (!sipMeth)
    {
         ::QStyle::customEvent(a0);
        return;
    }

    extern void sipVH_QtWidgets_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_QtWidgets_1(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStyle::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[28],sipPySelf,SIP_NULLPTR,sipName_connectNotify);

    if (!sipMeth)
    {
         ::QStyle::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQStyle::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[29],sipPySelf,SIP_NULLPTR,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::QStyle::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_QtWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QStyle_polish, "polish(self, QWidget)\n"
"polish(self, QApplication)\n"
"polish(self, QPalette) -> QPalette");

extern "C" {static PyObject *meth_QStyle_polish(PyObject *, PyObject *);}
static PyObject *meth_QStyle_polish(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QWidget* a0;
         ::QStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QWidget, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QStyle::polish(a0) : sipCpp->polish(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::QApplication* a0;
         ::QStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QApplication, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QStyle::polish(a0) : sipCpp->polish(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::QPalette* a0;
         ::QStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QStyle, &sipCpp, sipType_QPalette, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QStyle::polish(*a0) : sipCpp->polish(*a0));

            return sipConvertFromType(a0,sipType_QPalette,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_polish, doc_QStyle_polish);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_unpolish, "unpolish(self, QWidget)\n"
"unpolish(self, QApplication)");

extern "C" {static PyObject *meth_QStyle_unpolish(PyObject *, PyObject *);}
static PyObject *meth_QStyle_unpolish(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QWidget* a0;
         ::QStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QWidget, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QStyle::unpolish(a0) : sipCpp->unpolish(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
         ::QApplication* a0;
         ::QStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QApplication, &a0))
        {
            (sipSelfWasArg ? sipCpp-> ::QStyle::unpolish(a0) : sipCpp->unpolish(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_unpolish, doc_QStyle_unpolish);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_itemTextRect, "itemTextRect(self, QFontMetrics, QRect, int, bool, str) -> QRect");

extern "C" {static PyObject *meth_QStyle_itemTextRect(PyObject *, PyObject *);}
static PyObject *meth_QStyle_itemTextRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QFontMetrics* a0;
        const  ::QRect* a1;
        int a2;
        bool a3;
        const  ::QString* a4;
        int a4State = 0;
        const  ::QStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9ibJ1", &sipSelf, sipType_QStyle, &sipCpp, sipType_QFontMetrics, &a0, sipType_QRect, &a1, &a2, &a3, sipType_QString,&a4, &a4State))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect((sipSelfWasArg ? sipCpp-> ::QStyle::itemTextRect(*a0,*a1,a2,a3,*a4) : sipCpp->itemTextRect(*a0,*a1,a2,a3,*a4)));
            sipReleaseType(const_cast< ::QString *>(a4),sipType_QString,a4State);

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_itemTextRect, doc_QStyle_itemTextRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_itemPixmapRect, "itemPixmapRect(self, QRect, int, QPixmap) -> QRect");

extern "C" {static PyObject *meth_QStyle_itemPixmapRect(PyObject *, PyObject *);}
static PyObject *meth_QStyle_itemPixmapRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QRect* a0;
        int a1;
        const  ::QPixmap* a2;
        const  ::QStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9iJ9", &sipSelf, sipType_QStyle, &sipCpp, sipType_QRect, &a0, &a1, sipType_QPixmap, &a2))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect((sipSelfWasArg ? sipCpp-> ::QStyle::itemPixmapRect(*a0,a1,*a2) : sipCpp->itemPixmapRect(*a0,a1,*a2)));

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_itemPixmapRect, doc_QStyle_itemPixmapRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_drawItemText, "drawItemText(self, QPainter, QRect, int, QPalette, bool, str, textRole: QPalette.ColorRole = QPalette.NoRole)");

extern "C" {static PyObject *meth_QStyle_drawItemText(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_drawItemText(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QPainter* a0;
        const  ::QRect* a1;
        int a2;
        const  ::QPalette* a3;
        bool a4;
        const  ::QString* a5;
        int a5State = 0;
         ::QPalette::ColorRole a6 = QPalette::NoRole;
        const  ::QStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_textRole,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8J9iJ9bJ1|E", &sipSelf, sipType_QStyle, &sipCpp, sipType_QPainter, &a0, sipType_QRect, &a1, &a2, sipType_QPalette, &a3, &a4, sipType_QString,&a5, &a5State, sipType_QPalette_ColorRole, &a6))
        {
            (sipSelfWasArg ? sipCpp-> ::QStyle::drawItemText(a0,*a1,a2,*a3,a4,*a5,a6) : sipCpp->drawItemText(a0,*a1,a2,*a3,a4,*a5,a6));
            sipReleaseType(const_cast< ::QString *>(a5),sipType_QString,a5State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_drawItemText, doc_QStyle_drawItemText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_drawItemPixmap, "drawItemPixmap(self, QPainter, QRect, int, QPixmap)");

extern "C" {static PyObject *meth_QStyle_drawItemPixmap(PyObject *, PyObject *);}
static PyObject *meth_QStyle_drawItemPixmap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QPainter* a0;
        const  ::QRect* a1;
        int a2;
        const  ::QPixmap* a3;
        const  ::QStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8J9iJ9", &sipSelf, sipType_QStyle, &sipCpp, sipType_QPainter, &a0, sipType_QRect, &a1, &a2, sipType_QPixmap, &a3))
        {
            (sipSelfWasArg ? sipCpp-> ::QStyle::drawItemPixmap(a0,*a1,a2,*a3) : sipCpp->drawItemPixmap(a0,*a1,a2,*a3));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_drawItemPixmap, doc_QStyle_drawItemPixmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_standardPalette, "standardPalette(self) -> QPalette");

extern "C" {static PyObject *meth_QStyle_standardPalette(PyObject *, PyObject *);}
static PyObject *meth_QStyle_standardPalette(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyle, &sipCpp))
        {
             ::QPalette*sipRes;

            sipRes = new  ::QPalette((sipSelfWasArg ? sipCpp-> ::QStyle::standardPalette() : sipCpp->standardPalette()));

            return sipConvertFromNewType(sipRes,sipType_QPalette,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_standardPalette, doc_QStyle_standardPalette);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_drawPrimitive, "drawPrimitive(self, QStyle.PrimitiveElement, QStyleOption, QPainter, widget: QWidget = None)");

extern "C" {static PyObject *meth_QStyle_drawPrimitive(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_drawPrimitive(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QStyle::PrimitiveElement a0;
        const  ::QStyleOption* a1;
         ::QPainter* a2;
        const  ::QWidget* a3 = 0;
        const  ::QStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ8J8|J8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QStyle_PrimitiveElement, &a0, sipType_QStyleOption, &a1, sipType_QPainter, &a2, sipType_QWidget, &a3))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QStyle, sipName_drawPrimitive);
                return SIP_NULLPTR;
            }

            sipCpp->drawPrimitive(a0,a1,a2,a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_drawPrimitive, doc_QStyle_drawPrimitive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_drawControl, "drawControl(self, QStyle.ControlElement, QStyleOption, QPainter, widget: QWidget = None)");

extern "C" {static PyObject *meth_QStyle_drawControl(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_drawControl(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QStyle::ControlElement a0;
        const  ::QStyleOption* a1;
         ::QPainter* a2;
        const  ::QWidget* a3 = 0;
        const  ::QStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ8J8|J8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QStyle_ControlElement, &a0, sipType_QStyleOption, &a1, sipType_QPainter, &a2, sipType_QWidget, &a3))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QStyle, sipName_drawControl);
                return SIP_NULLPTR;
            }

            sipCpp->drawControl(a0,a1,a2,a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_drawControl, doc_QStyle_drawControl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_subElementRect, "subElementRect(self, QStyle.SubElement, QStyleOption, widget: QWidget = None) -> QRect");

extern "C" {static PyObject *meth_QStyle_subElementRect(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_subElementRect(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QStyle::SubElement a0;
        const  ::QStyleOption* a1;
        const  ::QWidget* a2 = 0;
        const  ::QStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ8|J8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QStyle_SubElement, &a0, sipType_QStyleOption, &a1, sipType_QWidget, &a2))
        {
             ::QRect*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QStyle, sipName_subElementRect);
                return SIP_NULLPTR;
            }

            sipRes = new  ::QRect(sipCpp->subElementRect(a0,a1,a2));

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_subElementRect, doc_QStyle_subElementRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_drawComplexControl, "drawComplexControl(self, QStyle.ComplexControl, QStyleOptionComplex, QPainter, widget: QWidget = None)");

extern "C" {static PyObject *meth_QStyle_drawComplexControl(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_drawComplexControl(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QStyle::ComplexControl a0;
        const  ::QStyleOptionComplex* a1;
         ::QPainter* a2;
        const  ::QWidget* a3 = 0;
        const  ::QStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ8J8|J8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QStyle_ComplexControl, &a0, sipType_QStyleOptionComplex, &a1, sipType_QPainter, &a2, sipType_QWidget, &a3))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QStyle, sipName_drawComplexControl);
                return SIP_NULLPTR;
            }

            sipCpp->drawComplexControl(a0,a1,a2,a3);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_drawComplexControl, doc_QStyle_drawComplexControl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_hitTestComplexControl, "hitTestComplexControl(self, QStyle.ComplexControl, QStyleOptionComplex, QPoint, widget: QWidget = None) -> QStyle.SubControl");

extern "C" {static PyObject *meth_QStyle_hitTestComplexControl(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_hitTestComplexControl(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QStyle::ComplexControl a0;
        const  ::QStyleOptionComplex* a1;
        const  ::QPoint* a2;
        const  ::QWidget* a3 = 0;
        const  ::QStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ8J9|J8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QStyle_ComplexControl, &a0, sipType_QStyleOptionComplex, &a1, sipType_QPoint, &a2, sipType_QWidget, &a3))
        {
             ::QStyle::SubControl sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QStyle, sipName_hitTestComplexControl);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->hitTestComplexControl(a0,a1,*a2,a3);

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QStyle_SubControl);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_hitTestComplexControl, doc_QStyle_hitTestComplexControl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_subControlRect, "subControlRect(self, QStyle.ComplexControl, QStyleOptionComplex, QStyle.SubControl, widget: QWidget = None) -> QRect");

extern "C" {static PyObject *meth_QStyle_subControlRect(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_subControlRect(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QStyle::ComplexControl a0;
        const  ::QStyleOptionComplex* a1;
         ::QStyle::SubControl a2;
        const  ::QWidget* a3 = 0;
        const  ::QStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ8E|J8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QStyle_ComplexControl, &a0, sipType_QStyleOptionComplex, &a1, sipType_QStyle_SubControl, &a2, sipType_QWidget, &a3))
        {
             ::QRect*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QStyle, sipName_subControlRect);
                return SIP_NULLPTR;
            }

            sipRes = new  ::QRect(sipCpp->subControlRect(a0,a1,a2,a3));

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_subControlRect, doc_QStyle_subControlRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_pixelMetric, "pixelMetric(self, QStyle.PixelMetric, option: QStyleOption = None, widget: QWidget = None) -> int");

extern "C" {static PyObject *meth_QStyle_pixelMetric(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_pixelMetric(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QStyle::PixelMetric a0;
        const  ::QStyleOption* a1 = 0;
        const  ::QWidget* a2 = 0;
        const  ::QStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_option,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|J8J8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QStyle_PixelMetric, &a0, sipType_QStyleOption, &a1, sipType_QWidget, &a2))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QStyle, sipName_pixelMetric);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->pixelMetric(a0,a1,a2);

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_pixelMetric, doc_QStyle_pixelMetric);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_sizeFromContents, "sizeFromContents(self, QStyle.ContentsType, QStyleOption, QSize, widget: QWidget = None) -> QSize");

extern "C" {static PyObject *meth_QStyle_sizeFromContents(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_sizeFromContents(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QStyle::ContentsType a0;
        const  ::QStyleOption* a1;
        const  ::QSize* a2;
        const  ::QWidget* a3 = 0;
        const  ::QStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEJ8J9|J8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QStyle_ContentsType, &a0, sipType_QStyleOption, &a1, sipType_QSize, &a2, sipType_QWidget, &a3))
        {
             ::QSize*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QStyle, sipName_sizeFromContents);
                return SIP_NULLPTR;
            }

            sipRes = new  ::QSize(sipCpp->sizeFromContents(a0,a1,*a2,a3));

            return sipConvertFromNewType(sipRes,sipType_QSize,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_sizeFromContents, doc_QStyle_sizeFromContents);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_styleHint, "styleHint(self, QStyle.StyleHint, option: QStyleOption = None, widget: QWidget = None, returnData: QStyleHintReturn = None) -> int");

extern "C" {static PyObject *meth_QStyle_styleHint(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_styleHint(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QStyle::StyleHint a0;
        const  ::QStyleOption* a1 = 0;
        const  ::QWidget* a2 = 0;
         ::QStyleHintReturn* a3 = 0;
        const  ::QStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_option,
            sipName_widget,
            sipName_returnData,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|J8J8J8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QStyle_StyleHint, &a0, sipType_QStyleOption, &a1, sipType_QWidget, &a2, sipType_QStyleHintReturn, &a3))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QStyle, sipName_styleHint);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->styleHint(a0,a1,a2,a3);

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_styleHint, doc_QStyle_styleHint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_standardPixmap, "standardPixmap(self, QStyle.StandardPixmap, option: QStyleOption = None, widget: QWidget = None) -> QPixmap");

extern "C" {static PyObject *meth_QStyle_standardPixmap(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_standardPixmap(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QStyle::StandardPixmap a0;
        const  ::QStyleOption* a1 = 0;
        const  ::QWidget* a2 = 0;
        const  ::QStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_option,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|J8J8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QStyle_StandardPixmap, &a0, sipType_QStyleOption, &a1, sipType_QWidget, &a2))
        {
             ::QPixmap*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QStyle, sipName_standardPixmap);
                return SIP_NULLPTR;
            }

            sipRes = new  ::QPixmap(sipCpp->standardPixmap(a0,a1,a2));

            return sipConvertFromNewType(sipRes,sipType_QPixmap,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_standardPixmap, doc_QStyle_standardPixmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_standardIcon, "standardIcon(self, QStyle.StandardPixmap, option: QStyleOption = None, widget: QWidget = None) -> QIcon");

extern "C" {static PyObject *meth_QStyle_standardIcon(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_standardIcon(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QStyle::StandardPixmap a0;
        const  ::QStyleOption* a1 = 0;
        const  ::QWidget* a2 = 0;
        const  ::QStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_option,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|J8J8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QStyle_StandardPixmap, &a0, sipType_QStyleOption, &a1, sipType_QWidget, &a2))
        {
             ::QIcon*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QStyle, sipName_standardIcon);
                return SIP_NULLPTR;
            }

            sipRes = new  ::QIcon(sipCpp->standardIcon(a0,a1,a2));

            return sipConvertFromNewType(sipRes,sipType_QIcon,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_standardIcon, doc_QStyle_standardIcon);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_generatedIconPixmap, "generatedIconPixmap(self, QIcon.Mode, QPixmap, QStyleOption) -> QPixmap");

extern "C" {static PyObject *meth_QStyle_generatedIconPixmap(PyObject *, PyObject *);}
static PyObject *meth_QStyle_generatedIconPixmap(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QIcon::Mode a0;
        const  ::QPixmap* a1;
        const  ::QStyleOption* a2;
        const  ::QStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BEJ9J8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QIcon_Mode, &a0, sipType_QPixmap, &a1, sipType_QStyleOption, &a2))
        {
             ::QPixmap*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QStyle, sipName_generatedIconPixmap);
                return SIP_NULLPTR;
            }

            sipRes = new  ::QPixmap(sipCpp->generatedIconPixmap(a0,*a1,a2));

            return sipConvertFromNewType(sipRes,sipType_QPixmap,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_generatedIconPixmap, doc_QStyle_generatedIconPixmap);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_visualRect, "visualRect(Qt.LayoutDirection, QRect, QRect) -> QRect");

extern "C" {static PyObject *meth_QStyle_visualRect(PyObject *, PyObject *);}
static PyObject *meth_QStyle_visualRect(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::LayoutDirection a0;
        const  ::QRect* a1;
        const  ::QRect* a2;

        if (sipParseArgs(&sipParseErr, sipArgs, "EJ9J9", sipType_Qt_LayoutDirection, &a0, sipType_QRect, &a1, sipType_QRect, &a2))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect( ::QStyle::visualRect(a0,*a1,*a2));

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_visualRect, doc_QStyle_visualRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_visualPos, "visualPos(Qt.LayoutDirection, QRect, QPoint) -> QPoint");

extern "C" {static PyObject *meth_QStyle_visualPos(PyObject *, PyObject *);}
static PyObject *meth_QStyle_visualPos(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::LayoutDirection a0;
        const  ::QRect* a1;
        const  ::QPoint* a2;

        if (sipParseArgs(&sipParseErr, sipArgs, "EJ9J9", sipType_Qt_LayoutDirection, &a0, sipType_QRect, &a1, sipType_QPoint, &a2))
        {
             ::QPoint*sipRes;

            sipRes = new  ::QPoint( ::QStyle::visualPos(a0,*a1,*a2));

            return sipConvertFromNewType(sipRes,sipType_QPoint,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_visualPos, doc_QStyle_visualPos);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_sliderPositionFromValue, "sliderPositionFromValue(int, int, int, int, upsideDown: bool = False) -> int");

extern "C" {static PyObject *meth_QStyle_sliderPositionFromValue(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_sliderPositionFromValue(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;
        int a3;
        bool a4 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_upsideDown,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "iiii|b", &a0, &a1, &a2, &a3, &a4))
        {
            int sipRes;

            sipRes =  ::QStyle::sliderPositionFromValue(a0,a1,a2,a3,a4);

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_sliderPositionFromValue, doc_QStyle_sliderPositionFromValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_sliderValueFromPosition, "sliderValueFromPosition(int, int, int, int, upsideDown: bool = False) -> int");

extern "C" {static PyObject *meth_QStyle_sliderValueFromPosition(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_sliderValueFromPosition(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        int a2;
        int a3;
        bool a4 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_upsideDown,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "iiii|b", &a0, &a1, &a2, &a3, &a4))
        {
            int sipRes;

            sipRes =  ::QStyle::sliderValueFromPosition(a0,a1,a2,a3,a4);

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_sliderValueFromPosition, doc_QStyle_sliderValueFromPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_visualAlignment, "visualAlignment(Qt.LayoutDirection, Union[Qt.Alignment, Qt.AlignmentFlag]) -> Qt.Alignment");

extern "C" {static PyObject *meth_QStyle_visualAlignment(PyObject *, PyObject *);}
static PyObject *meth_QStyle_visualAlignment(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::LayoutDirection a0;
         ::Qt::Alignment* a1;
        int a1State = 0;

        if (sipParseArgs(&sipParseErr, sipArgs, "EJ1", sipType_Qt_LayoutDirection, &a0, sipType_Qt_Alignment, &a1, &a1State))
        {
             ::Qt::Alignment*sipRes;

            sipRes = new  ::Qt::Alignment( ::QStyle::visualAlignment(a0,*a1));
            sipReleaseType(a1,sipType_Qt_Alignment,a1State);

            return sipConvertFromNewType(sipRes,sipType_Qt_Alignment,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_visualAlignment, doc_QStyle_visualAlignment);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_alignedRect, "alignedRect(Qt.LayoutDirection, Union[Qt.Alignment, Qt.AlignmentFlag], QSize, QRect) -> QRect");

extern "C" {static PyObject *meth_QStyle_alignedRect(PyObject *, PyObject *);}
static PyObject *meth_QStyle_alignedRect(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::Qt::LayoutDirection a0;
         ::Qt::Alignment* a1;
        int a1State = 0;
        const  ::QSize* a2;
        const  ::QRect* a3;

        if (sipParseArgs(&sipParseErr, sipArgs, "EJ1J9J9", sipType_Qt_LayoutDirection, &a0, sipType_Qt_Alignment, &a1, &a1State, sipType_QSize, &a2, sipType_QRect, &a3))
        {
             ::QRect*sipRes;

            sipRes = new  ::QRect( ::QStyle::alignedRect(a0,*a1,*a2,*a3));
            sipReleaseType(a1,sipType_Qt_Alignment,a1State);

            return sipConvertFromNewType(sipRes,sipType_QRect,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_alignedRect, doc_QStyle_alignedRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_layoutSpacing, "layoutSpacing(self, QSizePolicy.ControlType, QSizePolicy.ControlType, Qt.Orientation, option: QStyleOption = None, widget: QWidget = None) -> int");

extern "C" {static PyObject *meth_QStyle_layoutSpacing(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_layoutSpacing(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
         ::QSizePolicy::ControlType a0;
         ::QSizePolicy::ControlType a1;
         ::Qt::Orientation a2;
        const  ::QStyleOption* a3 = 0;
        const  ::QWidget* a4 = 0;
        const  ::QStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_option,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BEEE|J8J8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QSizePolicy_ControlType, &a0, sipType_QSizePolicy_ControlType, &a1, sipType_Qt_Orientation, &a2, sipType_QStyleOption, &a3, sipType_QWidget, &a4))
        {
            int sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QStyle, sipName_layoutSpacing);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->layoutSpacing(a0,a1,a2,a3,a4);

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_layoutSpacing, doc_QStyle_layoutSpacing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_combinedLayoutSpacing, "combinedLayoutSpacing(self, Union[QSizePolicy.ControlTypes, QSizePolicy.ControlType], Union[QSizePolicy.ControlTypes, QSizePolicy.ControlType], Qt.Orientation, option: QStyleOption = None, widget: QWidget = None) -> int");

extern "C" {static PyObject *meth_QStyle_combinedLayoutSpacing(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QStyle_combinedLayoutSpacing(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
         ::QSizePolicy::ControlTypes* a0;
        int a0State = 0;
         ::QSizePolicy::ControlTypes* a1;
        int a1State = 0;
         ::Qt::Orientation a2;
         ::QStyleOption* a3 = 0;
         ::QWidget* a4 = 0;
        const  ::QStyle *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_option,
            sipName_widget,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1J1E|J8J8", &sipSelf, sipType_QStyle, &sipCpp, sipType_QSizePolicy_ControlTypes, &a0, &a0State, sipType_QSizePolicy_ControlTypes, &a1, &a1State, sipType_Qt_Orientation, &a2, sipType_QStyleOption, &a3, sipType_QWidget, &a4))
        {
            int sipRes;

            sipRes = sipCpp->combinedLayoutSpacing(*a0,*a1,a2,a3,a4);
            sipReleaseType(a0,sipType_QSizePolicy_ControlTypes,a0State);
            sipReleaseType(a1,sipType_QSizePolicy_ControlTypes,a1State);

            return SIPLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_combinedLayoutSpacing, doc_QStyle_combinedLayoutSpacing);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QStyle_proxy, "proxy(self) -> QStyle");

extern "C" {static PyObject *meth_QStyle_proxy(PyObject *, PyObject *);}
static PyObject *meth_QStyle_proxy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const  ::QStyle *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QStyle, &sipCpp))
        {
            const  ::QStyle*sipRes;

            sipRes = sipCpp->proxy();

            return sipConvertFromType(const_cast< ::QStyle *>(sipRes),sipType_QStyle,SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QStyle, sipName_proxy, doc_QStyle_proxy);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QStyle(void *, const sipTypeDef *);}
static void *cast_QStyle(void *sipCppV, const sipTypeDef *targetType)
{
     ::QStyle *sipCpp = reinterpret_cast< ::QStyle *>(sipCppV);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_QStyle(void *, int);}
static void release_QStyle(void *sipCppV, int)
{
     ::QStyle *sipCpp = reinterpret_cast< ::QStyle *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QStyle(sipSimpleWrapper *);}
static void dealloc_QStyle(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQStyle *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QStyle(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QStyle(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QStyle(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    sipQStyle *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new sipQStyle();

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QStyle[] = {{34, 0, 1}};


static PyMethodDef methods_QStyle[] = {
    {SIP_MLNAME_CAST(sipName_alignedRect), meth_QStyle_alignedRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyle_alignedRect)},
    {SIP_MLNAME_CAST(sipName_combinedLayoutSpacing), SIP_MLMETH_CAST(meth_QStyle_combinedLayoutSpacing), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_combinedLayoutSpacing)},
    {SIP_MLNAME_CAST(sipName_drawComplexControl), SIP_MLMETH_CAST(meth_QStyle_drawComplexControl), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_drawComplexControl)},
    {SIP_MLNAME_CAST(sipName_drawControl), SIP_MLMETH_CAST(meth_QStyle_drawControl), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_drawControl)},
    {SIP_MLNAME_CAST(sipName_drawItemPixmap), meth_QStyle_drawItemPixmap, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyle_drawItemPixmap)},
    {SIP_MLNAME_CAST(sipName_drawItemText), SIP_MLMETH_CAST(meth_QStyle_drawItemText), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_drawItemText)},
    {SIP_MLNAME_CAST(sipName_drawPrimitive), SIP_MLMETH_CAST(meth_QStyle_drawPrimitive), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_drawPrimitive)},
    {SIP_MLNAME_CAST(sipName_generatedIconPixmap), meth_QStyle_generatedIconPixmap, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyle_generatedIconPixmap)},
    {SIP_MLNAME_CAST(sipName_hitTestComplexControl), SIP_MLMETH_CAST(meth_QStyle_hitTestComplexControl), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_hitTestComplexControl)},
    {SIP_MLNAME_CAST(sipName_itemPixmapRect), meth_QStyle_itemPixmapRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyle_itemPixmapRect)},
    {SIP_MLNAME_CAST(sipName_itemTextRect), meth_QStyle_itemTextRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyle_itemTextRect)},
    {SIP_MLNAME_CAST(sipName_layoutSpacing), SIP_MLMETH_CAST(meth_QStyle_layoutSpacing), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_layoutSpacing)},
    {SIP_MLNAME_CAST(sipName_pixelMetric), SIP_MLMETH_CAST(meth_QStyle_pixelMetric), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_pixelMetric)},
    {SIP_MLNAME_CAST(sipName_polish), meth_QStyle_polish, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyle_polish)},
    {SIP_MLNAME_CAST(sipName_proxy), meth_QStyle_proxy, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyle_proxy)},
    {SIP_MLNAME_CAST(sipName_sizeFromContents), SIP_MLMETH_CAST(meth_QStyle_sizeFromContents), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_sizeFromContents)},
    {SIP_MLNAME_CAST(sipName_sliderPositionFromValue), SIP_MLMETH_CAST(meth_QStyle_sliderPositionFromValue), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_sliderPositionFromValue)},
    {SIP_MLNAME_CAST(sipName_sliderValueFromPosition), SIP_MLMETH_CAST(meth_QStyle_sliderValueFromPosition), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_sliderValueFromPosition)},
    {SIP_MLNAME_CAST(sipName_standardIcon), SIP_MLMETH_CAST(meth_QStyle_standardIcon), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_standardIcon)},
    {SIP_MLNAME_CAST(sipName_standardPalette), meth_QStyle_standardPalette, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyle_standardPalette)},
    {SIP_MLNAME_CAST(sipName_standardPixmap), SIP_MLMETH_CAST(meth_QStyle_standardPixmap), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_standardPixmap)},
    {SIP_MLNAME_CAST(sipName_styleHint), SIP_MLMETH_CAST(meth_QStyle_styleHint), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_styleHint)},
    {SIP_MLNAME_CAST(sipName_subControlRect), SIP_MLMETH_CAST(meth_QStyle_subControlRect), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_subControlRect)},
    {SIP_MLNAME_CAST(sipName_subElementRect), SIP_MLMETH_CAST(meth_QStyle_subElementRect), METH_VARARGS|METH_KEYWORDS, SIP_MLDOC_CAST(doc_QStyle_subElementRect)},
    {SIP_MLNAME_CAST(sipName_unpolish), meth_QStyle_unpolish, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyle_unpolish)},
    {SIP_MLNAME_CAST(sipName_visualAlignment), meth_QStyle_visualAlignment, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyle_visualAlignment)},
    {SIP_MLNAME_CAST(sipName_visualPos), meth_QStyle_visualPos, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyle_visualPos)},
    {SIP_MLNAME_CAST(sipName_visualRect), meth_QStyle_visualRect, METH_VARARGS, SIP_MLDOC_CAST(doc_QStyle_visualRect)}
};

static sipEnumMemberDef enummembers_QStyle[] = {
    {sipName_CC_ComboBox, static_cast<int>( ::QStyle::CC_ComboBox), 291},
    {sipName_CC_CustomBase, static_cast<int>( ::QStyle::CC_CustomBase), 291},
    {sipName_CC_Dial, static_cast<int>( ::QStyle::CC_Dial), 291},
    {sipName_CC_GroupBox, static_cast<int>( ::QStyle::CC_GroupBox), 291},
    {sipName_CC_MdiControls, static_cast<int>( ::QStyle::CC_MdiControls), 291},
    {sipName_CC_ScrollBar, static_cast<int>( ::QStyle::CC_ScrollBar), 291},
    {sipName_CC_Slider, static_cast<int>( ::QStyle::CC_Slider), 291},
    {sipName_CC_SpinBox, static_cast<int>( ::QStyle::CC_SpinBox), 291},
    {sipName_CC_TitleBar, static_cast<int>( ::QStyle::CC_TitleBar), 291},
    {sipName_CC_ToolButton, static_cast<int>( ::QStyle::CC_ToolButton), 291},
    {sipName_CE_CheckBox, static_cast<int>( ::QStyle::CE_CheckBox), 293},
    {sipName_CE_CheckBoxLabel, static_cast<int>( ::QStyle::CE_CheckBoxLabel), 293},
    {sipName_CE_ColumnViewGrip, static_cast<int>( ::QStyle::CE_ColumnViewGrip), 293},
    {sipName_CE_ComboBoxLabel, static_cast<int>( ::QStyle::CE_ComboBoxLabel), 293},
    {sipName_CE_CustomBase, static_cast<int>( ::QStyle::CE_CustomBase), 293},
    {sipName_CE_DockWidgetTitle, static_cast<int>( ::QStyle::CE_DockWidgetTitle), 293},
    {sipName_CE_FocusFrame, static_cast<int>( ::QStyle::CE_FocusFrame), 293},
    {sipName_CE_Header, static_cast<int>( ::QStyle::CE_Header), 293},
    {sipName_CE_HeaderEmptyArea, static_cast<int>( ::QStyle::CE_HeaderEmptyArea), 293},
    {sipName_CE_HeaderLabel, static_cast<int>( ::QStyle::CE_HeaderLabel), 293},
    {sipName_CE_HeaderSection, static_cast<int>( ::QStyle::CE_HeaderSection), 293},
    {sipName_CE_ItemViewItem, static_cast<int>( ::QStyle::CE_ItemViewItem), 293},
    {sipName_CE_MenuBarEmptyArea, static_cast<int>( ::QStyle::CE_MenuBarEmptyArea), 293},
    {sipName_CE_MenuBarItem, static_cast<int>( ::QStyle::CE_MenuBarItem), 293},
    {sipName_CE_MenuEmptyArea, static_cast<int>( ::QStyle::CE_MenuEmptyArea), 293},
    {sipName_CE_MenuHMargin, static_cast<int>( ::QStyle::CE_MenuHMargin), 293},
    {sipName_CE_MenuItem, static_cast<int>( ::QStyle::CE_MenuItem), 293},
    {sipName_CE_MenuScroller, static_cast<int>( ::QStyle::CE_MenuScroller), 293},
    {sipName_CE_MenuTearoff, static_cast<int>( ::QStyle::CE_MenuTearoff), 293},
    {sipName_CE_MenuVMargin, static_cast<int>( ::QStyle::CE_MenuVMargin), 293},
    {sipName_CE_ProgressBar, static_cast<int>( ::QStyle::CE_ProgressBar), 293},
    {sipName_CE_ProgressBarContents, static_cast<int>( ::QStyle::CE_ProgressBarContents), 293},
    {sipName_CE_ProgressBarGroove, static_cast<int>( ::QStyle::CE_ProgressBarGroove), 293},
    {sipName_CE_ProgressBarLabel, static_cast<int>( ::QStyle::CE_ProgressBarLabel), 293},
    {sipName_CE_PushButton, static_cast<int>( ::QStyle::CE_PushButton), 293},
    {sipName_CE_PushButtonBevel, static_cast<int>( ::QStyle::CE_PushButtonBevel), 293},
    {sipName_CE_PushButtonLabel, static_cast<int>( ::QStyle::CE_PushButtonLabel), 293},
    {sipName_CE_RadioButton, static_cast<int>( ::QStyle::CE_RadioButton), 293},
    {sipName_CE_RadioButtonLabel, static_cast<int>( ::QStyle::CE_RadioButtonLabel), 293},
    {sipName_CE_RubberBand, static_cast<int>( ::QStyle::CE_RubberBand), 293},
    {sipName_CE_ScrollBarAddLine, static_cast<int>( ::QStyle::CE_ScrollBarAddLine), 293},
    {sipName_CE_ScrollBarAddPage, static_cast<int>( ::QStyle::CE_ScrollBarAddPage), 293},
    {sipName_CE_ScrollBarFirst, static_cast<int>( ::QStyle::CE_ScrollBarFirst), 293},
    {sipName_CE_ScrollBarLast, static_cast<int>( ::QStyle::CE_ScrollBarLast), 293},
    {sipName_CE_ScrollBarSlider, static_cast<int>( ::QStyle::CE_ScrollBarSlider), 293},
    {sipName_CE_ScrollBarSubLine, static_cast<int>( ::QStyle::CE_ScrollBarSubLine), 293},
    {sipName_CE_ScrollBarSubPage, static_cast<int>( ::QStyle::CE_ScrollBarSubPage), 293},
    {sipName_CE_ShapedFrame, static_cast<int>( ::QStyle::CE_ShapedFrame), 293},
    {sipName_CE_SizeGrip, static_cast<int>( ::QStyle::CE_SizeGrip), 293},
    {sipName_CE_Splitter, static_cast<int>( ::QStyle::CE_Splitter), 293},
    {sipName_CE_TabBarTab, static_cast<int>( ::QStyle::CE_TabBarTab), 293},
    {sipName_CE_TabBarTabLabel, static_cast<int>( ::QStyle::CE_TabBarTabLabel), 293},
    {sipName_CE_TabBarTabShape, static_cast<int>( ::QStyle::CE_TabBarTabShape), 293},
    {sipName_CE_ToolBar, static_cast<int>( ::QStyle::CE_ToolBar), 293},
    {sipName_CE_ToolBoxTab, static_cast<int>( ::QStyle::CE_ToolBoxTab), 293},
    {sipName_CE_ToolBoxTabLabel, static_cast<int>( ::QStyle::CE_ToolBoxTabLabel), 293},
    {sipName_CE_ToolBoxTabShape, static_cast<int>( ::QStyle::CE_ToolBoxTabShape), 293},
    {sipName_CE_ToolButtonLabel, static_cast<int>( ::QStyle::CE_ToolButtonLabel), 293},
    {sipName_CT_CheckBox, static_cast<int>( ::QStyle::CT_CheckBox), 292},
    {sipName_CT_ComboBox, static_cast<int>( ::QStyle::CT_ComboBox), 292},
    {sipName_CT_CustomBase, static_cast<int>( ::QStyle::CT_CustomBase), 292},
    {sipName_CT_DialogButtons, static_cast<int>( ::QStyle::CT_DialogButtons), 292},
    {sipName_CT_GroupBox, static_cast<int>( ::QStyle::CT_GroupBox), 292},
    {sipName_CT_HeaderSection, static_cast<int>( ::QStyle::CT_HeaderSection), 292},
    {sipName_CT_ItemViewItem, static_cast<int>( ::QStyle::CT_ItemViewItem), 292},
    {sipName_CT_LineEdit, static_cast<int>( ::QStyle::CT_LineEdit), 292},
    {sipName_CT_MdiControls, static_cast<int>( ::QStyle::CT_MdiControls), 292},
    {sipName_CT_Menu, static_cast<int>( ::QStyle::CT_Menu), 292},
    {sipName_CT_MenuBar, static_cast<int>( ::QStyle::CT_MenuBar), 292},
    {sipName_CT_MenuBarItem, static_cast<int>( ::QStyle::CT_MenuBarItem), 292},
    {sipName_CT_MenuItem, static_cast<int>( ::QStyle::CT_MenuItem), 292},
    {sipName_CT_ProgressBar, static_cast<int>( ::QStyle::CT_ProgressBar), 292},
    {sipName_CT_PushButton, static_cast<int>( ::QStyle::CT_PushButton), 292},
    {sipName_CT_RadioButton, static_cast<int>( ::QStyle::CT_RadioButton), 292},
    {sipName_CT_ScrollBar, static_cast<int>( ::QStyle::CT_ScrollBar), 292},
    {sipName_CT_SizeGrip, static_cast<int>( ::QStyle::CT_SizeGrip), 292},
    {sipName_CT_Slider, static_cast<int>( ::QStyle::CT_Slider), 292},
    {sipName_CT_SpinBox, static_cast<int>( ::QStyle::CT_SpinBox), 292},
    {sipName_CT_Splitter, static_cast<int>( ::QStyle::CT_Splitter), 292},
    {sipName_CT_TabBarTab, static_cast<int>( ::QStyle::CT_TabBarTab), 292},
    {sipName_CT_TabWidget, static_cast<int>( ::QStyle::CT_TabWidget), 292},
    {sipName_CT_ToolButton, static_cast<int>( ::QStyle::CT_ToolButton), 292},
    {sipName_PE_CustomBase, static_cast<int>( ::QStyle::PE_CustomBase), 295},
    {sipName_PE_Frame, static_cast<int>( ::QStyle::PE_Frame), 295},
    {sipName_PE_FrameButtonBevel, static_cast<int>( ::QStyle::PE_FrameButtonBevel), 295},
    {sipName_PE_FrameButtonTool, static_cast<int>( ::QStyle::PE_FrameButtonTool), 295},
    {sipName_PE_FrameDefaultButton, static_cast<int>( ::QStyle::PE_FrameDefaultButton), 295},
    {sipName_PE_FrameDockWidget, static_cast<int>( ::QStyle::PE_FrameDockWidget), 295},
    {sipName_PE_FrameFocusRect, static_cast<int>( ::QStyle::PE_FrameFocusRect), 295},
    {sipName_PE_FrameGroupBox, static_cast<int>( ::QStyle::PE_FrameGroupBox), 295},
    {sipName_PE_FrameLineEdit, static_cast<int>( ::QStyle::PE_FrameLineEdit), 295},
    {sipName_PE_FrameMenu, static_cast<int>( ::QStyle::PE_FrameMenu), 295},
    {sipName_PE_FrameStatusBar, static_cast<int>( ::QStyle::PE_FrameStatusBar), 295},
    {sipName_PE_FrameStatusBarItem, static_cast<int>( ::QStyle::PE_FrameStatusBarItem), 295},
    {sipName_PE_FrameTabBarBase, static_cast<int>( ::QStyle::PE_FrameTabBarBase), 295},
    {sipName_PE_FrameTabWidget, static_cast<int>( ::QStyle::PE_FrameTabWidget), 295},
    {sipName_PE_FrameWindow, static_cast<int>( ::QStyle::PE_FrameWindow), 295},
    {sipName_PE_IndicatorArrowDown, static_cast<int>( ::QStyle::PE_IndicatorArrowDown), 295},
    {sipName_PE_IndicatorArrowLeft, static_cast<int>( ::QStyle::PE_IndicatorArrowLeft), 295},
    {sipName_PE_IndicatorArrowRight, static_cast<int>( ::QStyle::PE_IndicatorArrowRight), 295},
    {sipName_PE_IndicatorArrowUp, static_cast<int>( ::QStyle::PE_IndicatorArrowUp), 295},
    {sipName_PE_IndicatorBranch, static_cast<int>( ::QStyle::PE_IndicatorBranch), 295},
    {sipName_PE_IndicatorButtonDropDown, static_cast<int>( ::QStyle::PE_IndicatorButtonDropDown), 295},
    {sipName_PE_IndicatorCheckBox, static_cast<int>( ::QStyle::PE_IndicatorCheckBox), 295},
    {sipName_PE_IndicatorColumnViewArrow, static_cast<int>( ::QStyle::PE_IndicatorColumnViewArrow), 295},
    {sipName_PE_IndicatorDockWidgetResizeHandle, static_cast<int>( ::QStyle::PE_IndicatorDockWidgetResizeHandle), 295},
    {sipName_PE_IndicatorHeaderArrow, static_cast<int>( ::QStyle::PE_IndicatorHeaderArrow), 295},
    {sipName_PE_IndicatorItemViewItemCheck, static_cast<int>( ::QStyle::PE_IndicatorItemViewItemCheck), 295},
    {sipName_PE_IndicatorItemViewItemDrop, static_cast<int>( ::QStyle::PE_IndicatorItemViewItemDrop), 295},
    {sipName_PE_IndicatorMenuCheckMark, static_cast<int>( ::QStyle::PE_IndicatorMenuCheckMark), 295},
    {sipName_PE_IndicatorProgressChunk, static_cast<int>( ::QStyle::PE_IndicatorProgressChunk), 295},
    {sipName_PE_IndicatorRadioButton, static_cast<int>( ::QStyle::PE_IndicatorRadioButton), 295},
    {sipName_PE_IndicatorSpinDown, static_cast<int>( ::QStyle::PE_IndicatorSpinDown), 295},
    {sipName_PE_IndicatorSpinMinus, static_cast<int>( ::QStyle::PE_IndicatorSpinMinus), 295},
    {sipName_PE_IndicatorSpinPlus, static_cast<int>( ::QStyle::PE_IndicatorSpinPlus), 295},
    {sipName_PE_IndicatorSpinUp, static_cast<int>( ::QStyle::PE_IndicatorSpinUp), 295},
    {sipName_PE_IndicatorTabClose, static_cast<int>( ::QStyle::PE_IndicatorTabClose), 295},
    {sipName_PE_IndicatorTabTear, static_cast<int>( ::QStyle::PE_IndicatorTabTear), 295},
    {sipName_PE_IndicatorTabTearLeft, static_cast<int>( ::QStyle::PE_IndicatorTabTearLeft), 295},
    {sipName_PE_IndicatorTabTearRight, static_cast<int>( ::QStyle::PE_IndicatorTabTearRight), 295},
    {sipName_PE_IndicatorToolBarHandle, static_cast<int>( ::QStyle::PE_IndicatorToolBarHandle), 295},
    {sipName_PE_IndicatorToolBarSeparator, static_cast<int>( ::QStyle::PE_IndicatorToolBarSeparator), 295},
    {sipName_PE_IndicatorViewItemCheck, static_cast<int>( ::QStyle::PE_IndicatorViewItemCheck), 295},
    {sipName_PE_PanelButtonBevel, static_cast<int>( ::QStyle::PE_PanelButtonBevel), 295},
    {sipName_PE_PanelButtonCommand, static_cast<int>( ::QStyle::PE_PanelButtonCommand), 295},
    {sipName_PE_PanelButtonTool, static_cast<int>( ::QStyle::PE_PanelButtonTool), 295},
    {sipName_PE_PanelItemViewItem, static_cast<int>( ::QStyle::PE_PanelItemViewItem), 295},
    {sipName_PE_PanelItemViewRow, static_cast<int>( ::QStyle::PE_PanelItemViewRow), 295},
    {sipName_PE_PanelLineEdit, static_cast<int>( ::QStyle::PE_PanelLineEdit), 295},
    {sipName_PE_PanelMenu, static_cast<int>( ::QStyle::PE_PanelMenu), 295},
    {sipName_PE_PanelMenuBar, static_cast<int>( ::QStyle::PE_PanelMenuBar), 295},
    {sipName_PE_PanelScrollAreaCorner, static_cast<int>( ::QStyle::PE_PanelScrollAreaCorner), 295},
    {sipName_PE_PanelStatusBar, static_cast<int>( ::QStyle::PE_PanelStatusBar), 295},
    {sipName_PE_PanelTipLabel, static_cast<int>( ::QStyle::PE_PanelTipLabel), 295},
    {sipName_PE_PanelToolBar, static_cast<int>( ::QStyle::PE_PanelToolBar), 295},
    {sipName_PE_Widget, static_cast<int>( ::QStyle::PE_Widget), 295},
    {sipName_PM_ButtonDefaultIndicator, static_cast<int>( ::QStyle::PM_ButtonDefaultIndicator), 294},
    {sipName_PM_ButtonIconSize, static_cast<int>( ::QStyle::PM_ButtonIconSize), 294},
    {sipName_PM_ButtonMargin, static_cast<int>( ::QStyle::PM_ButtonMargin), 294},
    {sipName_PM_ButtonShiftHorizontal, static_cast<int>( ::QStyle::PM_ButtonShiftHorizontal), 294},
    {sipName_PM_ButtonShiftVertical, static_cast<int>( ::QStyle::PM_ButtonShiftVertical), 294},
    {sipName_PM_CheckBoxLabelSpacing, static_cast<int>( ::QStyle::PM_CheckBoxLabelSpacing), 294},
    {sipName_PM_ComboBoxFrameWidth, static_cast<int>( ::QStyle::PM_ComboBoxFrameWidth), 294},
    {sipName_PM_CustomBase, static_cast<int>( ::QStyle::PM_CustomBase), 294},
    {sipName_PM_DefaultChildMargin, static_cast<int>( ::QStyle::PM_DefaultChildMargin), 294},
    {sipName_PM_DefaultFrameWidth, static_cast<int>( ::QStyle::PM_DefaultFrameWidth), 294},
    {sipName_PM_DefaultLayoutSpacing, static_cast<int>( ::QStyle::PM_DefaultLayoutSpacing), 294},
    {sipName_PM_DefaultTopLevelMargin, static_cast<int>( ::QStyle::PM_DefaultTopLevelMargin), 294},
    {sipName_PM_DialogButtonsButtonHeight, static_cast<int>( ::QStyle::PM_DialogButtonsButtonHeight), 294},
    {sipName_PM_DialogButtonsButtonWidth, static_cast<int>( ::QStyle::PM_DialogButtonsButtonWidth), 294},
    {sipName_PM_DialogButtonsSeparator, static_cast<int>( ::QStyle::PM_DialogButtonsSeparator), 294},
    {sipName_PM_DockWidgetFrameWidth, static_cast<int>( ::QStyle::PM_DockWidgetFrameWidth), 294},
    {sipName_PM_DockWidgetHandleExtent, static_cast<int>( ::QStyle::PM_DockWidgetHandleExtent), 294},
    {sipName_PM_DockWidgetSeparatorExtent, static_cast<int>( ::QStyle::PM_DockWidgetSeparatorExtent), 294},
    {sipName_PM_DockWidgetTitleBarButtonMargin, static_cast<int>( ::QStyle::PM_DockWidgetTitleBarButtonMargin), 294},
    {sipName_PM_DockWidgetTitleMargin, static_cast<int>( ::QStyle::PM_DockWidgetTitleMargin), 294},
    {sipName_PM_ExclusiveIndicatorHeight, static_cast<int>( ::QStyle::PM_ExclusiveIndicatorHeight), 294},
    {sipName_PM_ExclusiveIndicatorWidth, static_cast<int>( ::QStyle::PM_ExclusiveIndicatorWidth), 294},
    {sipName_PM_FocusFrameHMargin, static_cast<int>( ::QStyle::PM_FocusFrameHMargin), 294},
    {sipName_PM_FocusFrameVMargin, static_cast<int>( ::QStyle::PM_FocusFrameVMargin), 294},
    {sipName_PM_HeaderDefaultSectionSizeHorizontal, static_cast<int>( ::QStyle::PM_HeaderDefaultSectionSizeHorizontal), 294},
    {sipName_PM_HeaderDefaultSectionSizeVertical, static_cast<int>( ::QStyle::PM_HeaderDefaultSectionSizeVertical), 294},
    {sipName_PM_HeaderGripMargin, static_cast<int>( ::QStyle::PM_HeaderGripMargin), 294},
    {sipName_PM_HeaderMargin, static_cast<int>( ::QStyle::PM_HeaderMargin), 294},
    {sipName_PM_HeaderMarkSize, static_cast<int>( ::QStyle::PM_HeaderMarkSize), 294},
    {sipName_PM_IconViewIconSize, static_cast<int>( ::QStyle::PM_IconViewIconSize), 294},
    {sipName_PM_IndicatorHeight, static_cast<int>( ::QStyle::PM_IndicatorHeight), 294},
    {sipName_PM_IndicatorWidth, static_cast<int>( ::QStyle::PM_IndicatorWidth), 294},
    {sipName_PM_LargeIconSize, static_cast<int>( ::QStyle::PM_LargeIconSize), 294},
    {sipName_PM_LayoutBottomMargin, static_cast<int>( ::QStyle::PM_LayoutBottomMargin), 294},
    {sipName_PM_LayoutHorizontalSpacing, static_cast<int>( ::QStyle::PM_LayoutHorizontalSpacing), 294},
    {sipName_PM_LayoutLeftMargin, static_cast<int>( ::QStyle::PM_LayoutLeftMargin), 294},
    {sipName_PM_LayoutRightMargin, static_cast<int>( ::QStyle::PM_LayoutRightMargin), 294},
    {sipName_PM_LayoutTopMargin, static_cast<int>( ::QStyle::PM_LayoutTopMargin), 294},
    {sipName_PM_LayoutVerticalSpacing, static_cast<int>( ::QStyle::PM_LayoutVerticalSpacing), 294},
    {sipName_PM_ListViewIconSize, static_cast<int>( ::QStyle::PM_ListViewIconSize), 294},
    {sipName_PM_MDIFrameWidth, static_cast<int>( ::QStyle::PM_MDIFrameWidth), 294},
    {sipName_PM_MDIMinimizedWidth, static_cast<int>( ::QStyle::PM_MDIMinimizedWidth), 294},
    {sipName_PM_MaximumDragDistance, static_cast<int>( ::QStyle::PM_MaximumDragDistance), 294},
    {sipName_PM_MdiSubWindowFrameWidth, static_cast<int>( ::QStyle::PM_MdiSubWindowFrameWidth), 294},
    {sipName_PM_MdiSubWindowMinimizedWidth, static_cast<int>( ::QStyle::PM_MdiSubWindowMinimizedWidth), 294},
    {sipName_PM_MenuBarHMargin, static_cast<int>( ::QStyle::PM_MenuBarHMargin), 294},
    {sipName_PM_MenuBarItemSpacing, static_cast<int>( ::QStyle::PM_MenuBarItemSpacing), 294},
    {sipName_PM_MenuBarPanelWidth, static_cast<int>( ::QStyle::PM_MenuBarPanelWidth), 294},
    {sipName_PM_MenuBarVMargin, static_cast<int>( ::QStyle::PM_MenuBarVMargin), 294},
    {sipName_PM_MenuButtonIndicator, static_cast<int>( ::QStyle::PM_MenuButtonIndicator), 294},
    {sipName_PM_MenuDesktopFrameWidth, static_cast<int>( ::QStyle::PM_MenuDesktopFrameWidth), 294},
    {sipName_PM_MenuHMargin, static_cast<int>( ::QStyle::PM_MenuHMargin), 294},
    {sipName_PM_MenuPanelWidth, static_cast<int>( ::QStyle::PM_MenuPanelWidth), 294},
    {sipName_PM_MenuScrollerHeight, static_cast<int>( ::QStyle::PM_MenuScrollerHeight), 294},
    {sipName_PM_MenuTearoffHeight, static_cast<int>( ::QStyle::PM_MenuTearoffHeight), 294},
    {sipName_PM_MenuVMargin, static_cast<int>( ::QStyle::PM_MenuVMargin), 294},
    {sipName_PM_MessageBoxIconSize, static_cast<int>( ::QStyle::PM_MessageBoxIconSize), 294},
    {sipName_PM_ProgressBarChunkWidth, static_cast<int>( ::QStyle::PM_ProgressBarChunkWidth), 294},
    {sipName_PM_RadioButtonLabelSpacing, static_cast<int>( ::QStyle::PM_RadioButtonLabelSpacing), 294},
    {sipName_PM_ScrollBarExtent, static_cast<int>( ::QStyle::PM_ScrollBarExtent), 294},
    {sipName_PM_ScrollBarSliderMin, static_cast<int>( ::QStyle::PM_ScrollBarSliderMin), 294},
    {sipName_PM_ScrollView_ScrollBarOverlap, static_cast<int>( ::QStyle::PM_ScrollView_ScrollBarOverlap), 294},
    {sipName_PM_ScrollView_ScrollBarSpacing, static_cast<int>( ::QStyle::PM_ScrollView_ScrollBarSpacing), 294},
    {sipName_PM_SizeGripSize, static_cast<int>( ::QStyle::PM_SizeGripSize), 294},
    {sipName_PM_SliderControlThickness, static_cast<int>( ::QStyle::PM_SliderControlThickness), 294},
    {sipName_PM_SliderLength, static_cast<int>( ::QStyle::PM_SliderLength), 294},
    {sipName_PM_SliderSpaceAvailable, static_cast<int>( ::QStyle::PM_SliderSpaceAvailable), 294},
    {sipName_PM_SliderThickness, static_cast<int>( ::QStyle::PM_SliderThickness), 294},
    {sipName_PM_SliderTickmarkOffset, static_cast<int>( ::QStyle::PM_SliderTickmarkOffset), 294},
    {sipName_PM_SmallIconSize, static_cast<int>( ::QStyle::PM_SmallIconSize), 294},
    {sipName_PM_SpinBoxFrameWidth, static_cast<int>( ::QStyle::PM_SpinBoxFrameWidth), 294},
    {sipName_PM_SpinBoxSliderHeight, static_cast<int>( ::QStyle::PM_SpinBoxSliderHeight), 294},
    {sipName_PM_SplitterWidth, static_cast<int>( ::QStyle::PM_SplitterWidth), 294},
    {sipName_PM_SubMenuOverlap, static_cast<int>( ::QStyle::PM_SubMenuOverlap), 294},
    {sipName_PM_TabBarBaseHeight, static_cast<int>( ::QStyle::PM_TabBarBaseHeight), 294},
    {sipName_PM_TabBarBaseOverlap, static_cast<int>( ::QStyle::PM_TabBarBaseOverlap), 294},
    {sipName_PM_TabBarIconSize, static_cast<int>( ::QStyle::PM_TabBarIconSize), 294},
    {sipName_PM_TabBarScrollButtonWidth, static_cast<int>( ::QStyle::PM_TabBarScrollButtonWidth), 294},
    {sipName_PM_TabBarTabHSpace, static_cast<int>( ::QStyle::PM_TabBarTabHSpace), 294},
    {sipName_PM_TabBarTabOverlap, static_cast<int>( ::QStyle::PM_TabBarTabOverlap), 294},
    {sipName_PM_TabBarTabShiftHorizontal, static_cast<int>( ::QStyle::PM_TabBarTabShiftHorizontal), 294},
    {sipName_PM_TabBarTabShiftVertical, static_cast<int>( ::QStyle::PM_TabBarTabShiftVertical), 294},
    {sipName_PM_TabBarTabVSpace, static_cast<int>( ::QStyle::PM_TabBarTabVSpace), 294},
    {sipName_PM_TabBar_ScrollButtonOverlap, static_cast<int>( ::QStyle::PM_TabBar_ScrollButtonOverlap), 294},
    {sipName_PM_TabCloseIndicatorHeight, static_cast<int>( ::QStyle::PM_TabCloseIndicatorHeight), 294},
    {sipName_PM_TabCloseIndicatorWidth, static_cast<int>( ::QStyle::PM_TabCloseIndicatorWidth), 294},
    {sipName_PM_TextCursorWidth, static_cast<int>( ::QStyle::PM_TextCursorWidth), 294},
    {sipName_PM_TitleBarButtonIconSize, static_cast<int>( ::QStyle::PM_TitleBarButtonIconSize), 294},
    {sipName_PM_TitleBarButtonSize, static_cast<int>( ::QStyle::PM_TitleBarButtonSize), 294},
    {sipName_PM_TitleBarHeight, static_cast<int>( ::QStyle::PM_TitleBarHeight), 294},
    {sipName_PM_ToolBarExtensionExtent, static_cast<int>( ::QStyle::PM_ToolBarExtensionExtent), 294},
    {sipName_PM_ToolBarFrameWidth, static_cast<int>( ::QStyle::PM_ToolBarFrameWidth), 294},
    {sipName_PM_ToolBarHandleExtent, static_cast<int>( ::QStyle::PM_ToolBarHandleExtent), 294},
    {sipName_PM_ToolBarIconSize, static_cast<int>( ::QStyle::PM_ToolBarIconSize), 294},
    {sipName_PM_ToolBarItemMargin, static_cast<int>( ::QStyle::PM_ToolBarItemMargin), 294},
    {sipName_PM_ToolBarItemSpacing, static_cast<int>( ::QStyle::PM_ToolBarItemSpacing), 294},
    {sipName_PM_ToolBarSeparatorExtent, static_cast<int>( ::QStyle::PM_ToolBarSeparatorExtent), 294},
    {sipName_PM_ToolTipLabelFrameWidth, static_cast<int>( ::QStyle::PM_ToolTipLabelFrameWidth), 294},
    {sipName_PM_TreeViewIndentation, static_cast<int>( ::QStyle::PM_TreeViewIndentation), 294},
    {sipName_RSIP_OnMouseClick, static_cast<int>( ::QStyle::RSIP_OnMouseClick), 296},
    {sipName_RSIP_OnMouseClickAndAlreadyFocused, static_cast<int>( ::QStyle::RSIP_OnMouseClickAndAlreadyFocused), 296},
    {sipName_SC_All, static_cast<int>( ::QStyle::SC_All), 301},
    {sipName_SC_ComboBoxArrow, static_cast<int>( ::QStyle::SC_ComboBoxArrow), 301},
    {sipName_SC_ComboBoxEditField, static_cast<int>( ::QStyle::SC_ComboBoxEditField), 301},
    {sipName_SC_ComboBoxFrame, static_cast<int>( ::QStyle::SC_ComboBoxFrame), 301},
    {sipName_SC_ComboBoxListBoxPopup, static_cast<int>( ::QStyle::SC_ComboBoxListBoxPopup), 301},
    {sipName_SC_CustomBase, static_cast<int>( ::QStyle::SC_CustomBase), 301},
    {sipName_SC_DialGroove, static_cast<int>( ::QStyle::SC_DialGroove), 301},
    {sipName_SC_DialHandle, static_cast<int>( ::QStyle::SC_DialHandle), 301},
    {sipName_SC_DialTickmarks, static_cast<int>( ::QStyle::SC_DialTickmarks), 301},
    {sipName_SC_GroupBoxCheckBox, static_cast<int>( ::QStyle::SC_GroupBoxCheckBox), 301},
    {sipName_SC_GroupBoxContents, static_cast<int>( ::QStyle::SC_GroupBoxContents), 301},
    {sipName_SC_GroupBoxFrame, static_cast<int>( ::QStyle::SC_GroupBoxFrame), 301},
    {sipName_SC_GroupBoxLabel, static_cast<int>( ::QStyle::SC_GroupBoxLabel), 301},
    {sipName_SC_MdiCloseButton, static_cast<int>( ::QStyle::SC_MdiCloseButton), 301},
    {sipName_SC_MdiMinButton, static_cast<int>( ::QStyle::SC_MdiMinButton), 301},
    {sipName_SC_MdiNormalButton, static_cast<int>( ::QStyle::SC_MdiNormalButton), 301},
    {sipName_SC_None, static_cast<int>( ::QStyle::SC_None), 301},
    {sipName_SC_ScrollBarAddLine, static_cast<int>( ::QStyle::SC_ScrollBarAddLine), 301},
    {sipName_SC_ScrollBarAddPage, static_cast<int>( ::QStyle::SC_ScrollBarAddPage), 301},
    {sipName_SC_ScrollBarFirst, static_cast<int>( ::QStyle::SC_ScrollBarFirst), 301},
    {sipName_SC_ScrollBarGroove, static_cast<int>( ::QStyle::SC_ScrollBarGroove), 301},
    {sipName_SC_ScrollBarLast, static_cast<int>( ::QStyle::SC_ScrollBarLast), 301},
    {sipName_SC_ScrollBarSlider, static_cast<int>( ::QStyle::SC_ScrollBarSlider), 301},
    {sipName_SC_ScrollBarSubLine, static_cast<int>( ::QStyle::SC_ScrollBarSubLine), 301},
    {sipName_SC_ScrollBarSubPage, static_cast<int>( ::QStyle::SC_ScrollBarSubPage), 301},
    {sipName_SC_SliderGroove, static_cast<int>( ::QStyle::SC_SliderGroove), 301},
    {sipName_SC_SliderHandle, static_cast<int>( ::QStyle::SC_SliderHandle), 301},
    {sipName_SC_SliderTickmarks, static_cast<int>( ::QStyle::SC_SliderTickmarks), 301},
    {sipName_SC_SpinBoxDown, static_cast<int>( ::QStyle::SC_SpinBoxDown), 301},
    {sipName_SC_SpinBoxEditField, static_cast<int>( ::QStyle::SC_SpinBoxEditField), 301},
    {sipName_SC_SpinBoxFrame, static_cast<int>( ::QStyle::SC_SpinBoxFrame), 301},
    {sipName_SC_SpinBoxUp, static_cast<int>( ::QStyle::SC_SpinBoxUp), 301},
    {sipName_SC_TitleBarCloseButton, static_cast<int>( ::QStyle::SC_TitleBarCloseButton), 301},
    {sipName_SC_TitleBarContextHelpButton, static_cast<int>( ::QStyle::SC_TitleBarContextHelpButton), 301},
    {sipName_SC_TitleBarLabel, static_cast<int>( ::QStyle::SC_TitleBarLabel), 301},
    {sipName_SC_TitleBarMaxButton, static_cast<int>( ::QStyle::SC_TitleBarMaxButton), 301},
    {sipName_SC_TitleBarMinButton, static_cast<int>( ::QStyle::SC_TitleBarMinButton), 301},
    {sipName_SC_TitleBarNormalButton, static_cast<int>( ::QStyle::SC_TitleBarNormalButton), 301},
    {sipName_SC_TitleBarShadeButton, static_cast<int>( ::QStyle::SC_TitleBarShadeButton), 301},
    {sipName_SC_TitleBarSysMenu, static_cast<int>( ::QStyle::SC_TitleBarSysMenu), 301},
    {sipName_SC_TitleBarUnshadeButton, static_cast<int>( ::QStyle::SC_TitleBarUnshadeButton), 301},
    {sipName_SC_ToolButton, static_cast<int>( ::QStyle::SC_ToolButton), 301},
    {sipName_SC_ToolButtonMenu, static_cast<int>( ::QStyle::SC_ToolButtonMenu), 301},
    {sipName_SE_CheckBoxClickRect, static_cast<int>( ::QStyle::SE_CheckBoxClickRect), 303},
    {sipName_SE_CheckBoxContents, static_cast<int>( ::QStyle::SE_CheckBoxContents), 303},
    {sipName_SE_CheckBoxFocusRect, static_cast<int>( ::QStyle::SE_CheckBoxFocusRect), 303},
    {sipName_SE_CheckBoxIndicator, static_cast<int>( ::QStyle::SE_CheckBoxIndicator), 303},
    {sipName_SE_CheckBoxLayoutItem, static_cast<int>( ::QStyle::SE_CheckBoxLayoutItem), 303},
    {sipName_SE_ComboBoxFocusRect, static_cast<int>( ::QStyle::SE_ComboBoxFocusRect), 303},
    {sipName_SE_ComboBoxLayoutItem, static_cast<int>( ::QStyle::SE_ComboBoxLayoutItem), 303},
    {sipName_SE_CustomBase, static_cast<int>( ::QStyle::SE_CustomBase), 303},
    {sipName_SE_DateTimeEditLayoutItem, static_cast<int>( ::QStyle::SE_DateTimeEditLayoutItem), 303},
    {sipName_SE_DialogButtonBoxLayoutItem, static_cast<int>( ::QStyle::SE_DialogButtonBoxLayoutItem), 303},
    {sipName_SE_DockWidgetCloseButton, static_cast<int>( ::QStyle::SE_DockWidgetCloseButton), 303},
    {sipName_SE_DockWidgetFloatButton, static_cast<int>( ::QStyle::SE_DockWidgetFloatButton), 303},
    {sipName_SE_DockWidgetIcon, static_cast<int>( ::QStyle::SE_DockWidgetIcon), 303},
    {sipName_SE_DockWidgetTitleBarText, static_cast<int>( ::QStyle::SE_DockWidgetTitleBarText), 303},
    {sipName_SE_FrameContents, static_cast<int>( ::QStyle::SE_FrameContents), 303},
    {sipName_SE_FrameLayoutItem, static_cast<int>( ::QStyle::SE_FrameLayoutItem), 303},
    {sipName_SE_GroupBoxLayoutItem, static_cast<int>( ::QStyle::SE_GroupBoxLayoutItem), 303},
    {sipName_SE_HeaderArrow, static_cast<int>( ::QStyle::SE_HeaderArrow), 303},
    {sipName_SE_HeaderLabel, static_cast<int>( ::QStyle::SE_HeaderLabel), 303},
    {sipName_SE_ItemViewItemCheckIndicator, static_cast<int>( ::QStyle::SE_ItemViewItemCheckIndicator), 303},
    {sipName_SE_ItemViewItemDecoration, static_cast<int>( ::QStyle::SE_ItemViewItemDecoration), 303},
    {sipName_SE_ItemViewItemFocusRect, static_cast<int>( ::QStyle::SE_ItemViewItemFocusRect), 303},
    {sipName_SE_ItemViewItemText, static_cast<int>( ::QStyle::SE_ItemViewItemText), 303},
    {sipName_SE_LabelLayoutItem, static_cast<int>( ::QStyle::SE_LabelLayoutItem), 303},
    {sipName_SE_LineEditContents, static_cast<int>( ::QStyle::SE_LineEditContents), 303},
    {sipName_SE_ProgressBarContents, static_cast<int>( ::QStyle::SE_ProgressBarContents), 303},
    {sipName_SE_ProgressBarGroove, static_cast<int>( ::QStyle::SE_ProgressBarGroove), 303},
    {sipName_SE_ProgressBarLabel, static_cast<int>( ::QStyle::SE_ProgressBarLabel), 303},
    {sipName_SE_ProgressBarLayoutItem, static_cast<int>( ::QStyle::SE_ProgressBarLayoutItem), 303},
    {sipName_SE_PushButtonBevel, static_cast<int>( ::QStyle::SE_PushButtonBevel), 303},
    {sipName_SE_PushButtonContents, static_cast<int>( ::QStyle::SE_PushButtonContents), 303},
    {sipName_SE_PushButtonFocusRect, static_cast<int>( ::QStyle::SE_PushButtonFocusRect), 303},
    {sipName_SE_PushButtonLayoutItem, static_cast<int>( ::QStyle::SE_PushButtonLayoutItem), 303},
    {sipName_SE_RadioButtonClickRect, static_cast<int>( ::QStyle::SE_RadioButtonClickRect), 303},
    {sipName_SE_RadioButtonContents, static_cast<int>( ::QStyle::SE_RadioButtonContents), 303},
    {sipName_SE_RadioButtonFocusRect, static_cast<int>( ::QStyle::SE_RadioButtonFocusRect), 303},
    {sipName_SE_RadioButtonIndicator, static_cast<int>( ::QStyle::SE_RadioButtonIndicator), 303},
    {sipName_SE_RadioButtonLayoutItem, static_cast<int>( ::QStyle::SE_RadioButtonLayoutItem), 303},
    {sipName_SE_ShapedFrameContents, static_cast<int>( ::QStyle::SE_ShapedFrameContents), 303},
    {sipName_SE_SliderFocusRect, static_cast<int>( ::QStyle::SE_SliderFocusRect), 303},
    {sipName_SE_SliderLayoutItem, static_cast<int>( ::QStyle::SE_SliderLayoutItem), 303},
    {sipName_SE_SpinBoxLayoutItem, static_cast<int>( ::QStyle::SE_SpinBoxLayoutItem), 303},
    {sipName_SE_TabBarScrollLeftButton, static_cast<int>( ::QStyle::SE_TabBarScrollLeftButton), 303},
    {sipName_SE_TabBarScrollRightButton, static_cast<int>( ::QStyle::SE_TabBarScrollRightButton), 303},
    {sipName_SE_TabBarTabLeftButton, static_cast<int>( ::QStyle::SE_TabBarTabLeftButton), 303},
    {sipName_SE_TabBarTabRightButton, static_cast<int>( ::QStyle::SE_TabBarTabRightButton), 303},
    {sipName_SE_TabBarTabText, static_cast<int>( ::QStyle::SE_TabBarTabText), 303},
    {sipName_SE_TabBarTearIndicator, static_cast<int>( ::QStyle::SE_TabBarTearIndicator), 303},
    {sipName_SE_TabBarTearIndicatorLeft, static_cast<int>( ::QStyle::SE_TabBarTearIndicatorLeft), 303},
    {sipName_SE_TabBarTearIndicatorRight, static_cast<int>( ::QStyle::SE_TabBarTearIndicatorRight), 303},
    {sipName_SE_TabWidgetLayoutItem, static_cast<int>( ::QStyle::SE_TabWidgetLayoutItem), 303},
    {sipName_SE_TabWidgetLeftCorner, static_cast<int>( ::QStyle::SE_TabWidgetLeftCorner), 303},
    {sipName_SE_TabWidgetRightCorner, static_cast<int>( ::QStyle::SE_TabWidgetRightCorner), 303},
    {sipName_SE_TabWidgetTabBar, static_cast<int>( ::QStyle::SE_TabWidgetTabBar), 303},
    {sipName_SE_TabWidgetTabContents, static_cast<int>( ::QStyle::SE_TabWidgetTabContents), 303},
    {sipName_SE_TabWidgetTabPane, static_cast<int>( ::QStyle::SE_TabWidgetTabPane), 303},
    {sipName_SE_ToolBarHandle, static_cast<int>( ::QStyle::SE_ToolBarHandle), 303},
    {sipName_SE_ToolBoxTabContents, static_cast<int>( ::QStyle::SE_ToolBoxTabContents), 303},
    {sipName_SE_ToolButtonLayoutItem, static_cast<int>( ::QStyle::SE_ToolButtonLayoutItem), 303},
    {sipName_SE_TreeViewDisclosureItem, static_cast<int>( ::QStyle::SE_TreeViewDisclosureItem), 303},
    {sipName_SE_ViewItemCheckIndicator, static_cast<int>( ::QStyle::SE_ViewItemCheckIndicator), 303},
    {sipName_SH_BlinkCursorWhenTextSelected, static_cast<int>( ::QStyle::SH_BlinkCursorWhenTextSelected), 300},
    {sipName_SH_Button_FocusPolicy, static_cast<int>( ::QStyle::SH_Button_FocusPolicy), 300},
    {sipName_SH_ComboBox_AllowWheelScrolling, static_cast<int>( ::QStyle::SH_ComboBox_AllowWheelScrolling), 300},
    {sipName_SH_ComboBox_LayoutDirection, static_cast<int>( ::QStyle::SH_ComboBox_LayoutDirection), 300},
    {sipName_SH_ComboBox_ListMouseTracking, static_cast<int>( ::QStyle::SH_ComboBox_ListMouseTracking), 300},
    {sipName_SH_ComboBox_Popup, static_cast<int>( ::QStyle::SH_ComboBox_Popup), 300},
    {sipName_SH_ComboBox_PopupFrameStyle, static_cast<int>( ::QStyle::SH_ComboBox_PopupFrameStyle), 300},
    {sipName_SH_CustomBase, static_cast<int>( ::QStyle::SH_CustomBase), 300},
    {sipName_SH_Dial_BackgroundRole, static_cast<int>( ::QStyle::SH_Dial_BackgroundRole), 300},
    {sipName_SH_DialogButtonBox_ButtonsHaveIcons, static_cast<int>( ::QStyle::SH_DialogButtonBox_ButtonsHaveIcons), 300},
    {sipName_SH_DialogButtonLayout, static_cast<int>( ::QStyle::SH_DialogButtonLayout), 300},
    {sipName_SH_DialogButtons_DefaultButton, static_cast<int>( ::QStyle::SH_DialogButtons_DefaultButton), 300},
    {sipName_SH_DitherDisabledText, static_cast<int>( ::QStyle::SH_DitherDisabledText), 300},
    {sipName_SH_DockWidget_ButtonsHaveFrame, static_cast<int>( ::QStyle::SH_DockWidget_ButtonsHaveFrame), 300},
    {sipName_SH_DrawMenuBarSeparator, static_cast<int>( ::QStyle::SH_DrawMenuBarSeparator), 300},
    {sipName_SH_EtchDisabledText, static_cast<int>( ::QStyle::SH_EtchDisabledText), 300},
    {sipName_SH_FocusFrame_AboveWidget, static_cast<int>( ::QStyle::SH_FocusFrame_AboveWidget), 300},
    {sipName_SH_FocusFrame_Mask, static_cast<int>( ::QStyle::SH_FocusFrame_Mask), 300},
    {sipName_SH_FontDialog_SelectAssociatedText, static_cast<int>( ::QStyle::SH_FontDialog_SelectAssociatedText), 300},
    {sipName_SH_FormLayoutFieldGrowthPolicy, static_cast<int>( ::QStyle::SH_FormLayoutFieldGrowthPolicy), 300},
    {sipName_SH_FormLayoutFormAlignment, static_cast<int>( ::QStyle::SH_FormLayoutFormAlignment), 300},
    {sipName_SH_FormLayoutLabelAlignment, static_cast<int>( ::QStyle::SH_FormLayoutLabelAlignment), 300},
    {sipName_SH_FormLayoutWrapPolicy, static_cast<int>( ::QStyle::SH_FormLayoutWrapPolicy), 300},
    {sipName_SH_GroupBox_TextLabelColor, static_cast<int>( ::QStyle::SH_GroupBox_TextLabelColor), 300},
    {sipName_SH_GroupBox_TextLabelVerticalAlignment, static_cast<int>( ::QStyle::SH_GroupBox_TextLabelVerticalAlignment), 300},
    {sipName_SH_Header_ArrowAlignment, static_cast<int>( ::QStyle::SH_Header_ArrowAlignment), 300},
    {sipName_SH_ItemView_ActivateItemOnSingleClick, static_cast<int>( ::QStyle::SH_ItemView_ActivateItemOnSingleClick), 300},
    {sipName_SH_ItemView_ArrowKeysNavigateIntoChildren, static_cast<int>( ::QStyle::SH_ItemView_ArrowKeysNavigateIntoChildren), 300},
    {sipName_SH_ItemView_ChangeHighlightOnFocus, static_cast<int>( ::QStyle::SH_ItemView_ChangeHighlightOnFocus), 300},
    {sipName_SH_ItemView_DrawDelegateFrame, static_cast<int>( ::QStyle::SH_ItemView_DrawDelegateFrame), 300},
    {sipName_SH_ItemView_EllipsisLocation, static_cast<int>( ::QStyle::SH_ItemView_EllipsisLocation), 300},
    {sipName_SH_ItemView_MovementWithoutUpdatingSelection, static_cast<int>( ::QStyle::SH_ItemView_MovementWithoutUpdatingSelection), 300},
    {sipName_SH_ItemView_PaintAlternatingRowColorsForEmptyArea, static_cast<int>( ::QStyle::SH_ItemView_PaintAlternatingRowColorsForEmptyArea), 300},
    {sipName_SH_ItemView_ScrollMode, static_cast<int>( ::QStyle::SH_ItemView_ScrollMode), 300},
    {sipName_SH_ItemView_ShowDecorationSelected, static_cast<int>( ::QStyle::SH_ItemView_ShowDecorationSelected), 300},
    {sipName_SH_LineEdit_PasswordCharacter, static_cast<int>( ::QStyle::SH_LineEdit_PasswordCharacter), 300},
    {sipName_SH_LineEdit_PasswordMaskDelay, static_cast<int>( ::QStyle::SH_LineEdit_PasswordMaskDelay), 300},
    {sipName_SH_ListViewExpand_SelectMouseType, static_cast<int>( ::QStyle::SH_ListViewExpand_SelectMouseType), 300},
    {sipName_SH_MainWindow_SpaceBelowMenuBar, static_cast<int>( ::QStyle::SH_MainWindow_SpaceBelowMenuBar), 300},
    {sipName_SH_MenuBar_AltKeyNavigation, static_cast<int>( ::QStyle::SH_MenuBar_AltKeyNavigation), 300},
    {sipName_SH_MenuBar_MouseTracking, static_cast<int>( ::QStyle::SH_MenuBar_MouseTracking), 300},
    {sipName_SH_Menu_AllowActiveAndDisabled, static_cast<int>( ::QStyle::SH_Menu_AllowActiveAndDisabled), 300},
    {sipName_SH_Menu_FadeOutOnHide, static_cast<int>( ::QStyle::SH_Menu_FadeOutOnHide), 300},
    {sipName_SH_Menu_FillScreenWithScroll, static_cast<int>( ::QStyle::SH_Menu_FillScreenWithScroll), 300},
    {sipName_SH_Menu_FlashTriggeredItem, static_cast<int>( ::QStyle::SH_Menu_FlashTriggeredItem), 300},
    {sipName_SH_Menu_KeyboardSearch, static_cast<int>( ::QStyle::SH_Menu_KeyboardSearch), 300},
    {sipName_SH_Menu_Mask, static_cast<int>( ::QStyle::SH_Menu_Mask), 300},
    {sipName_SH_Menu_MouseTracking, static_cast<int>( ::QStyle::SH_Menu_MouseTracking), 300},
    {sipName_SH_Menu_Scrollable, static_cast<int>( ::QStyle::SH_Menu_Scrollable), 300},
    {sipName_SH_Menu_SelectionWrap, static_cast<int>( ::QStyle::SH_Menu_SelectionWrap), 300},
    {sipName_SH_Menu_SloppySubMenus, static_cast<int>( ::QStyle::SH_Menu_SloppySubMenus), 300},
    {sipName_SH_Menu_SpaceActivatesItem, static_cast<int>( ::QStyle::SH_Menu_SpaceActivatesItem), 300},
    {sipName_SH_Menu_SubMenuDontStartSloppyOnLeave, static_cast<int>( ::QStyle::SH_Menu_SubMenuDontStartSloppyOnLeave), 300},
    {sipName_SH_Menu_SubMenuPopupDelay, static_cast<int>( ::QStyle::SH_Menu_SubMenuPopupDelay), 300},
    {sipName_SH_Menu_SubMenuResetWhenReenteringParent, static_cast<int>( ::QStyle::SH_Menu_SubMenuResetWhenReenteringParent), 300},
    {sipName_SH_Menu_SubMenuSloppyCloseTimeout, static_cast<int>( ::QStyle::SH_Menu_SubMenuSloppyCloseTimeout), 300},
    {sipName_SH_Menu_SubMenuSloppySelectOtherActions, static_cast<int>( ::QStyle::SH_Menu_SubMenuSloppySelectOtherActions), 300},
    {sipName_SH_Menu_SubMenuUniDirection, static_cast<int>( ::QStyle::SH_Menu_SubMenuUniDirection), 300},
    {sipName_SH_Menu_SubMenuUniDirectionFailCount, static_cast<int>( ::QStyle::SH_Menu_SubMenuUniDirectionFailCount), 300},
    {sipName_SH_Menu_SupportsSections, static_cast<int>( ::QStyle::SH_Menu_SupportsSections), 300},
    {sipName_SH_MessageBox_CenterButtons, static_cast<int>( ::QStyle::SH_MessageBox_CenterButtons), 300},
    {sipName_SH_MessageBox_TextInteractionFlags, static_cast<int>( ::QStyle::SH_MessageBox_TextInteractionFlags), 300},
    {sipName_SH_MessageBox_UseBorderForButtonSpacing, static_cast<int>( ::QStyle::SH_MessageBox_UseBorderForButtonSpacing), 300},
    {sipName_SH_PrintDialog_RightAlignButtons, static_cast<int>( ::QStyle::SH_PrintDialog_RightAlignButtons), 300},
    {sipName_SH_ProgressDialog_CenterCancelButton, static_cast<int>( ::QStyle::SH_ProgressDialog_CenterCancelButton), 300},
    {sipName_SH_ProgressDialog_TextLabelAlignment, static_cast<int>( ::QStyle::SH_ProgressDialog_TextLabelAlignment), 300},
    {sipName_SH_RequestSoftwareInputPanel, static_cast<int>( ::QStyle::SH_RequestSoftwareInputPanel), 300},
    {sipName_SH_RichText_FullWidthSelection, static_cast<int>( ::QStyle::SH_RichText_FullWidthSelection), 300},
    {sipName_SH_RubberBand_Mask, static_cast<int>( ::QStyle::SH_RubberBand_Mask), 300},
    {sipName_SH_ScrollBar_ContextMenu, static_cast<int>( ::QStyle::SH_ScrollBar_ContextMenu), 300},
    {sipName_SH_ScrollBar_LeftClickAbsolutePosition, static_cast<int>( ::QStyle::SH_ScrollBar_LeftClickAbsolutePosition), 300},
    {sipName_SH_ScrollBar_MiddleClickAbsolutePosition, static_cast<int>( ::QStyle::SH_ScrollBar_MiddleClickAbsolutePosition), 300},
    {sipName_SH_ScrollBar_RollBetweenButtons, static_cast<int>( ::QStyle::SH_ScrollBar_RollBetweenButtons), 300},
    {sipName_SH_ScrollBar_ScrollWhenPointerLeavesControl, static_cast<int>( ::QStyle::SH_ScrollBar_ScrollWhenPointerLeavesControl), 300},
    {sipName_SH_ScrollBar_StopMouseOverSlider, static_cast<int>( ::QStyle::SH_ScrollBar_StopMouseOverSlider), 300},
    {sipName_SH_ScrollBar_Transient, static_cast<int>( ::QStyle::SH_ScrollBar_Transient), 300},
    {sipName_SH_ScrollView_FrameOnlyAroundContents, static_cast<int>( ::QStyle::SH_ScrollView_FrameOnlyAroundContents), 300},
    {sipName_SH_Slider_AbsoluteSetButtons, static_cast<int>( ::QStyle::SH_Slider_AbsoluteSetButtons), 300},
    {sipName_SH_Slider_PageSetButtons, static_cast<int>( ::QStyle::SH_Slider_PageSetButtons), 300},
    {sipName_SH_Slider_SloppyKeyEvents, static_cast<int>( ::QStyle::SH_Slider_SloppyKeyEvents), 300},
    {sipName_SH_Slider_SnapToValue, static_cast<int>( ::QStyle::SH_Slider_SnapToValue), 300},
    {sipName_SH_Slider_StopMouseOverSlider, static_cast<int>( ::QStyle::SH_Slider_StopMouseOverSlider), 300},
    {sipName_SH_SpellCheckUnderlineStyle, static_cast<int>( ::QStyle::SH_SpellCheckUnderlineStyle), 300},
    {sipName_SH_SpinBox_AnimateButton, static_cast<int>( ::QStyle::SH_SpinBox_AnimateButton), 300},
    {sipName_SH_SpinBox_ButtonsInsideFrame, static_cast<int>( ::QStyle::SH_SpinBox_ButtonsInsideFrame), 300},
    {sipName_SH_SpinBox_ClickAutoRepeatRate, static_cast<int>( ::QStyle::SH_SpinBox_ClickAutoRepeatRate), 300},
    {sipName_SH_SpinBox_ClickAutoRepeatThreshold, static_cast<int>( ::QStyle::SH_SpinBox_ClickAutoRepeatThreshold), 300},
    {sipName_SH_SpinBox_KeyPressAutoRepeatRate, static_cast<int>( ::QStyle::SH_SpinBox_KeyPressAutoRepeatRate), 300},
    {sipName_SH_SpinBox_StepModifier, static_cast<int>( ::QStyle::SH_SpinBox_StepModifier), 300},
    {sipName_SH_SpinControls_DisableOnBounds, static_cast<int>( ::QStyle::SH_SpinControls_DisableOnBounds), 300},
    {sipName_SH_Splitter_OpaqueResize, static_cast<int>( ::QStyle::SH_Splitter_OpaqueResize), 300},
    {sipName_SH_TabBar_Alignment, static_cast<int>( ::QStyle::SH_TabBar_Alignment), 300},
    {sipName_SH_TabBar_ChangeCurrentDelay, static_cast<int>( ::QStyle::SH_TabBar_ChangeCurrentDelay), 300},
    {sipName_SH_TabBar_CloseButtonPosition, static_cast<int>( ::QStyle::SH_TabBar_CloseButtonPosition), 300},
    {sipName_SH_TabBar_ElideMode, static_cast<int>( ::QStyle::SH_TabBar_ElideMode), 300},
    {sipName_SH_TabBar_PreferNoArrows, static_cast<int>( ::QStyle::SH_TabBar_PreferNoArrows), 300},
    {sipName_SH_TabBar_SelectMouseType, static_cast<int>( ::QStyle::SH_TabBar_SelectMouseType), 300},
    {sipName_SH_TabWidget_DefaultTabPosition, static_cast<int>( ::QStyle::SH_TabWidget_DefaultTabPosition), 300},
    {sipName_SH_Table_GridLineColor, static_cast<int>( ::QStyle::SH_Table_GridLineColor), 300},
    {sipName_SH_TextControl_FocusIndicatorTextCharFormat, static_cast<int>( ::QStyle::SH_TextControl_FocusIndicatorTextCharFormat), 300},
    {sipName_SH_TitleBar_AutoRaise, static_cast<int>( ::QStyle::SH_TitleBar_AutoRaise), 300},
    {sipName_SH_TitleBar_ModifyNotification, static_cast<int>( ::QStyle::SH_TitleBar_ModifyNotification), 300},
    {sipName_SH_TitleBar_NoBorder, static_cast<int>( ::QStyle::SH_TitleBar_NoBorder), 300},
    {sipName_SH_TitleBar_ShowToolTipsOnButtons, static_cast<int>( ::QStyle::SH_TitleBar_ShowToolTipsOnButtons), 300},
    {sipName_SH_ToolBar_Movable, static_cast<int>( ::QStyle::SH_ToolBar_Movable), 300},
    {sipName_SH_ToolBox_SelectedPageTitleBold, static_cast<int>( ::QStyle::SH_ToolBox_SelectedPageTitleBold), 300},
    {sipName_SH_ToolButtonStyle, static_cast<int>( ::QStyle::SH_ToolButtonStyle), 300},
    {sipName_SH_ToolButton_PopupDelay, static_cast<int>( ::QStyle::SH_ToolButton_PopupDelay), 300},
    {sipName_SH_ToolTipLabel_Opacity, static_cast<int>( ::QStyle::SH_ToolTipLabel_Opacity), 300},
    {sipName_SH_ToolTip_FallAsleepDelay, static_cast<int>( ::QStyle::SH_ToolTip_FallAsleepDelay), 300},
    {sipName_SH_ToolTip_Mask, static_cast<int>( ::QStyle::SH_ToolTip_Mask), 300},
    {sipName_SH_ToolTip_WakeUpDelay, static_cast<int>( ::QStyle::SH_ToolTip_WakeUpDelay), 300},
    {sipName_SH_UnderlineShortcut, static_cast<int>( ::QStyle::SH_UnderlineShortcut), 300},
    {sipName_SH_Widget_Animate, static_cast<int>( ::QStyle::SH_Widget_Animate), 300},
    {sipName_SH_Widget_Animation_Duration, static_cast<int>( ::QStyle::SH_Widget_Animation_Duration), 300},
    {sipName_SH_Widget_ShareActivation, static_cast<int>( ::QStyle::SH_Widget_ShareActivation), 300},
    {sipName_SH_WindowFrame_Mask, static_cast<int>( ::QStyle::SH_WindowFrame_Mask), 300},
    {sipName_SH_WizardStyle, static_cast<int>( ::QStyle::SH_WizardStyle), 300},
    {sipName_SH_Workspace_FillSpaceOnMaximize, static_cast<int>( ::QStyle::SH_Workspace_FillSpaceOnMaximize), 300},
    {sipName_SP_ArrowBack, static_cast<int>( ::QStyle::SP_ArrowBack), 297},
    {sipName_SP_ArrowDown, static_cast<int>( ::QStyle::SP_ArrowDown), 297},
    {sipName_SP_ArrowForward, static_cast<int>( ::QStyle::SP_ArrowForward), 297},
    {sipName_SP_ArrowLeft, static_cast<int>( ::QStyle::SP_ArrowLeft), 297},
    {sipName_SP_ArrowRight, static_cast<int>( ::QStyle::SP_ArrowRight), 297},
    {sipName_SP_ArrowUp, static_cast<int>( ::QStyle::SP_ArrowUp), 297},
    {sipName_SP_BrowserReload, static_cast<int>( ::QStyle::SP_BrowserReload), 297},
    {sipName_SP_BrowserStop, static_cast<int>( ::QStyle::SP_BrowserStop), 297},
    {sipName_SP_CommandLink, static_cast<int>( ::QStyle::SP_CommandLink), 297},
    {sipName_SP_ComputerIcon, static_cast<int>( ::QStyle::SP_ComputerIcon), 297},
    {sipName_SP_CustomBase, static_cast<int>( ::QStyle::SP_CustomBase), 297},
    {sipName_SP_DesktopIcon, static_cast<int>( ::QStyle::SP_DesktopIcon), 297},
    {sipName_SP_DialogAbortButton, static_cast<int>( ::QStyle::SP_DialogAbortButton), 297},
    {sipName_SP_DialogApplyButton, static_cast<int>( ::QStyle::SP_DialogApplyButton), 297},
    {sipName_SP_DialogCancelButton, static_cast<int>( ::QStyle::SP_DialogCancelButton), 297},
    {sipName_SP_DialogCloseButton, static_cast<int>( ::QStyle::SP_DialogCloseButton), 297},
    {sipName_SP_DialogDiscardButton, static_cast<int>( ::QStyle::SP_DialogDiscardButton), 297},
    {sipName_SP_DialogHelpButton, static_cast<int>( ::QStyle::SP_DialogHelpButton), 297},
    {sipName_SP_DialogIgnoreButton, static_cast<int>( ::QStyle::SP_DialogIgnoreButton), 297},
    {sipName_SP_DialogNoButton, static_cast<int>( ::QStyle::SP_DialogNoButton), 297},
    {sipName_SP_DialogNoToAllButton, static_cast<int>( ::QStyle::SP_DialogNoToAllButton), 297},
    {sipName_SP_DialogOkButton, static_cast<int>( ::QStyle::SP_DialogOkButton), 297},
    {sipName_SP_DialogOpenButton, static_cast<int>( ::QStyle::SP_DialogOpenButton), 297},
    {sipName_SP_DialogResetButton, static_cast<int>( ::QStyle::SP_DialogResetButton), 297},
    {sipName_SP_DialogRetryButton, static_cast<int>( ::QStyle::SP_DialogRetryButton), 297},
    {sipName_SP_DialogSaveAllButton, static_cast<int>( ::QStyle::SP_DialogSaveAllButton), 297},
    {sipName_SP_DialogSaveButton, static_cast<int>( ::QStyle::SP_DialogSaveButton), 297},
    {sipName_SP_DialogYesButton, static_cast<int>( ::QStyle::SP_DialogYesButton), 297},
    {sipName_SP_DialogYesToAllButton, static_cast<int>( ::QStyle::SP_DialogYesToAllButton), 297},
    {sipName_SP_DirClosedIcon, static_cast<int>( ::QStyle::SP_DirClosedIcon), 297},
    {sipName_SP_DirHomeIcon, static_cast<int>( ::QStyle::SP_DirHomeIcon), 297},
    {sipName_SP_DirIcon, static_cast<int>( ::QStyle::SP_DirIcon), 297},
    {sipName_SP_DirLinkIcon, static_cast<int>( ::QStyle::SP_DirLinkIcon), 297},
    {sipName_SP_DirLinkOpenIcon, static_cast<int>( ::QStyle::SP_DirLinkOpenIcon), 297},
    {sipName_SP_DirOpenIcon, static_cast<int>( ::QStyle::SP_DirOpenIcon), 297},
    {sipName_SP_DockWidgetCloseButton, static_cast<int>( ::QStyle::SP_DockWidgetCloseButton), 297},
    {sipName_SP_DriveCDIcon, static_cast<int>( ::QStyle::SP_DriveCDIcon), 297},
    {sipName_SP_DriveDVDIcon, static_cast<int>( ::QStyle::SP_DriveDVDIcon), 297},
    {sipName_SP_DriveFDIcon, static_cast<int>( ::QStyle::SP_DriveFDIcon), 297},
    {sipName_SP_DriveHDIcon, static_cast<int>( ::QStyle::SP_DriveHDIcon), 297},
    {sipName_SP_DriveNetIcon, static_cast<int>( ::QStyle::SP_DriveNetIcon), 297},
    {sipName_SP_FileDialogBack, static_cast<int>( ::QStyle::SP_FileDialogBack), 297},
    {sipName_SP_FileDialogContentsView, static_cast<int>( ::QStyle::SP_FileDialogContentsView), 297},
    {sipName_SP_FileDialogDetailedView, static_cast<int>( ::QStyle::SP_FileDialogDetailedView), 297},
    {sipName_SP_FileDialogEnd, static_cast<int>( ::QStyle::SP_FileDialogEnd), 297},
    {sipName_SP_FileDialogInfoView, static_cast<int>( ::QStyle::SP_FileDialogInfoView), 297},
    {sipName_SP_FileDialogListView, static_cast<int>( ::QStyle::SP_FileDialogListView), 297},
    {sipName_SP_FileDialogNewFolder, static_cast<int>( ::QStyle::SP_FileDialogNewFolder), 297},
    {sipName_SP_FileDialogStart, static_cast<int>( ::QStyle::SP_FileDialogStart), 297},
    {sipName_SP_FileDialogToParent, static_cast<int>( ::QStyle::SP_FileDialogToParent), 297},
    {sipName_SP_FileIcon, static_cast<int>( ::QStyle::SP_FileIcon), 297},
    {sipName_SP_FileLinkIcon, static_cast<int>( ::QStyle::SP_FileLinkIcon), 297},
    {sipName_SP_LineEditClearButton, static_cast<int>( ::QStyle::SP_LineEditClearButton), 297},
    {sipName_SP_MediaPause, static_cast<int>( ::QStyle::SP_MediaPause), 297},
    {sipName_SP_MediaPlay, static_cast<int>( ::QStyle::SP_MediaPlay), 297},
    {sipName_SP_MediaSeekBackward, static_cast<int>( ::QStyle::SP_MediaSeekBackward), 297},
    {sipName_SP_MediaSeekForward, static_cast<int>( ::QStyle::SP_MediaSeekForward), 297},
    {sipName_SP_MediaSkipBackward, static_cast<int>( ::QStyle::SP_MediaSkipBackward), 297},
    {sipName_SP_MediaSkipForward, static_cast<int>( ::QStyle::SP_MediaSkipForward), 297},
    {sipName_SP_MediaStop, static_cast<int>( ::QStyle::SP_MediaStop), 297},
    {sipName_SP_MediaVolume, static_cast<int>( ::QStyle::SP_MediaVolume), 297},
    {sipName_SP_MediaVolumeMuted, static_cast<int>( ::QStyle::SP_MediaVolumeMuted), 297},
    {sipName_SP_MessageBoxCritical, static_cast<int>( ::QStyle::SP_MessageBoxCritical), 297},
    {sipName_SP_MessageBoxInformation, static_cast<int>( ::QStyle::SP_MessageBoxInformation), 297},
    {sipName_SP_MessageBoxQuestion, static_cast<int>( ::QStyle::SP_MessageBoxQuestion), 297},
    {sipName_SP_MessageBoxWarning, static_cast<int>( ::QStyle::SP_MessageBoxWarning), 297},
    {sipName_SP_RestoreDefaultsButton, static_cast<int>( ::QStyle::SP_RestoreDefaultsButton), 297},
    {sipName_SP_TitleBarCloseButton, static_cast<int>( ::QStyle::SP_TitleBarCloseButton), 297},
    {sipName_SP_TitleBarContextHelpButton, static_cast<int>( ::QStyle::SP_TitleBarContextHelpButton), 297},
    {sipName_SP_TitleBarMaxButton, static_cast<int>( ::QStyle::SP_TitleBarMaxButton), 297},
    {sipName_SP_TitleBarMenuButton, static_cast<int>( ::QStyle::SP_TitleBarMenuButton), 297},
    {sipName_SP_TitleBarMinButton, static_cast<int>( ::QStyle::SP_TitleBarMinButton), 297},
    {sipName_SP_TitleBarNormalButton, static_cast<int>( ::QStyle::SP_TitleBarNormalButton), 297},
    {sipName_SP_TitleBarShadeButton, static_cast<int>( ::QStyle::SP_TitleBarShadeButton), 297},
    {sipName_SP_TitleBarUnshadeButton, static_cast<int>( ::QStyle::SP_TitleBarUnshadeButton), 297},
    {sipName_SP_ToolBarHorizontalExtensionButton, static_cast<int>( ::QStyle::SP_ToolBarHorizontalExtensionButton), 297},
    {sipName_SP_ToolBarVerticalExtensionButton, static_cast<int>( ::QStyle::SP_ToolBarVerticalExtensionButton), 297},
    {sipName_SP_TrashIcon, static_cast<int>( ::QStyle::SP_TrashIcon), 297},
    {sipName_SP_VistaShield, static_cast<int>( ::QStyle::SP_VistaShield), 297},
    {sipName_State_Active, static_cast<int>( ::QStyle::State_Active), 299},
    {sipName_State_AutoRaise, static_cast<int>( ::QStyle::State_AutoRaise), 299},
    {sipName_State_Bottom, static_cast<int>( ::QStyle::State_Bottom), 299},
    {sipName_State_Children, static_cast<int>( ::QStyle::State_Children), 299},
    {sipName_State_DownArrow, static_cast<int>( ::QStyle::State_DownArrow), 299},
    {sipName_State_Editing, static_cast<int>( ::QStyle::State_Editing), 299},
    {sipName_State_Enabled, static_cast<int>( ::QStyle::State_Enabled), 299},
    {sipName_State_FocusAtBorder, static_cast<int>( ::QStyle::State_FocusAtBorder), 299},
    {sipName_State_HasFocus, static_cast<int>( ::QStyle::State_HasFocus), 299},
    {sipName_State_Horizontal, static_cast<int>( ::QStyle::State_Horizontal), 299},
    {sipName_State_Item, static_cast<int>( ::QStyle::State_Item), 299},
    {sipName_State_KeyboardFocusChange, static_cast<int>( ::QStyle::State_KeyboardFocusChange), 299},
    {sipName_State_Mini, static_cast<int>( ::QStyle::State_Mini), 299},
    {sipName_State_MouseOver, static_cast<int>( ::QStyle::State_MouseOver), 299},
    {sipName_State_NoChange, static_cast<int>( ::QStyle::State_NoChange), 299},
    {sipName_State_None, static_cast<int>( ::QStyle::State_None), 299},
    {sipName_State_Off, static_cast<int>( ::QStyle::State_Off), 299},
    {sipName_State_On, static_cast<int>( ::QStyle::State_On), 299},
    {sipName_State_Open, static_cast<int>( ::QStyle::State_Open), 299},
    {sipName_State_Raised, static_cast<int>( ::QStyle::State_Raised), 299},
    {sipName_State_ReadOnly, static_cast<int>( ::QStyle::State_ReadOnly), 299},
    {sipName_State_Selected, static_cast<int>( ::QStyle::State_Selected), 299},
    {sipName_State_Sibling, static_cast<int>( ::QStyle::State_Sibling), 299},
    {sipName_State_Small, static_cast<int>( ::QStyle::State_Small), 299},
    {sipName_State_Sunken, static_cast<int>( ::QStyle::State_Sunken), 299},
    {sipName_State_Top, static_cast<int>( ::QStyle::State_Top), 299},
    {sipName_State_UpArrow, static_cast<int>( ::QStyle::State_UpArrow), 299},
    {sipName_State_Window, static_cast<int>( ::QStyle::State_Window), 299},
};

PyDoc_STRVAR(doc_QStyle, "\1QStyle()");


static pyqt5ClassPluginDef plugin_QStyle = {
    & ::QStyle::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWidgets_QStyle = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QStyle,
        {SIP_NULLPTR},
        &plugin_QStyle
    },
    {
        sipNameNr_QStyle,
        {0, 0, 1},
        28, methods_QStyle,
        567, enummembers_QStyle,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QStyle,
    -1,
    -1,
    supers_QStyle,
    SIP_NULLPTR,
    init_type_QStyle,
    SIP_NULLPTR,
    SIP_NULLPTR,
#if PY_MAJOR_VERSION >= 3
    SIP_NULLPTR,
    SIP_NULLPTR,
#else
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
#endif
    dealloc_QStyle,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QStyle,
    cast_QStyle,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR
};
